<?php
namespace Backend\Controller;

use Backend\Controller\BackendController;
use Backend\Model\DealModel;
use Backend\Model\InvoiceModel;
use Common\Respository\DealRespository;
use Common\Respository\InvoiceRespository;

/**
 * | 后台控制器模板
 * |@author: duanbin
 * |@时间: 2016年9月28日 下午5:06:01
 * |@version: 1.0
 */
class DealController extends BackendController{
	

	/**
	 * 初始化仓储和模型
	 * @时间: 2016年10月9日 下午4:49:54
	 * @author: duanbin
	 */
	public function _initialize(){
		parent::_initialize();
		$this->model = new DealModel();
		$this->respository = new DealRespository($this->model);
	}
	
	/**
	 * 产品列表页
	 * @时间: 2016年9月30日 下午3:30:32
	 * @author: duanbin
	 */
	public function index(){
		//表头，排序相关数据
		$th = $this->model->getSortable();
		//获取表头里面真正有排序的字段
		$sorted = $this->model->getSortableField($th);
		//未加排序前缀的表头
		$th_raw = array_keys($this->model->sortable);
		//获取筛选字段的需要的数据,筛选所需要的字段
		$search = $this->model->getFillData()->getSearchable();
		//获取需要展示的字段，列表的表头
		$field = implode(',', array_keys($this->model->sortable));
		//获取所有的数据
		$data = $this->respository->finder($field);
		//获取统计数据
		$counter = $this->respository->counter($field);
		//获取有使用的产品类型
		$catNotTrialType = D('Common/ProductType')->getCanNotTrialType();
		//处理分页参数问题
		$current_page = empty(request()['p']) ? 1: request()['p'];
		$this->assign([
			'search' => $search,
			'th' => $th,
			'th_count' => count($th),	//表格列数
			'th_raw' => $th_raw,
			'sorted' => $sorted,	//真正可以排序的字段
			'data' => $data['data'],
			'sum_pages' => $data['sumPages'],
			'total' => $data['total'],
			'current_page' => $current_page,
			'per_page' => $data['perPage'],
			'pages' => $data['show'],
			'request' => request(),
			'catNotTrialType' => $catNotTrialType,
			'counter' => $counter,
		]);
		$this->display();
	}

	/**
	 * 获取发票申请列表
	 * @date: 2019年6月25日16:52:53
	 * @author: GuoPeng
	 * @return array|bool
	 */
	public function invoice(){
		$invoice = new InvoiceModel();
		$respository = new InvoiceRespository($invoice);
		$th = $invoice->getSortable();//表头，排序相关数据
		//获取表头里面真正有排序的字段
		$sorted = $invoice->getSortableField($th);
		//未加排序前缀的表头
		$th_raw = array_keys($invoice->sortable);
		//获取筛选字段的需要的数据,筛选所需要的字段
		$search = $invoice->getFillData()->getSearchable();
		//获取需要展示的字段，列表的表头
		$field = implode(',', array_keys($invoice->sortable));
		//获取所有的数据
		$data = $respository->finder($field);
		//获取统计数据
		$counter = $respository->counter($field);
		//处理分页参数问题
		$current_page = empty(request()['p']) ? 1: request()['p'];
		$this->assign([
			'search' => $search,
			'th' => $th,
			'th_count' => count($th),	//表格列数
			'th_raw' => $th_raw,
			'sorted' => $sorted,	//真正可以排序的字段
			'data' => $data['data'],
			'sum_pages' => $data['sumPages'],
			'total' => $data['total'],
			'current_page' => $current_page,
			'per_page' => $data['perPage'],
			'pages' => $data['show'],
			'request' => request(),
			'counter' => $counter,
		]);
		$this->display();
	}

	/**
	 * 完成发票申请
	 * @date: 2019年6月25日16:52:53
	 * @author: GuoPeng
	 */
	public function invoice_complete(){
		$invoice = new InvoiceModel();
		$res = $invoice->invoice_complete();
		if($res){
			$this->success("修改成功！","",true);
		}else{
			$this->error("修改失败！","",true);
		}
	}

	/**
	 * 删除发票申请
	 * @date: 2019年6月25日16:52:53
	 * @author: GuoPeng
	 */
	public function invoice_erase(){
		$invoice = new InvoiceModel();
		$res = $invoice->invoice_erase();
		if($res){
			$this->success("删除成功！","",true);
		}else{
			$this->error("删除失败！","",true);
		}
	}

	/**
	 * 拒绝发票申请
	 * @date: 2019年6月25日16:52:53
	 * @author: GuoPeng
	 */
	public function invoice_refuse(){
		$invoice = new InvoiceModel();
		$res = $invoice->invoice_refuse();
		if($res){
			$this->success("拒绝成功！","",true);
		}else{
			$this->error("拒绝失败！","",true);
		}
	}

	/**
	 * 修改发票金额
	 * @date: 2019年6月25日16:52:53
	 * @author: GuoPeng
	 */
	public function invoice_update(){
		$invoice = new InvoiceModel();
		$res = $invoice->invoice_update();
		if($res){
			$this->success("修改成功！","",true);
		}else{
			$this->error("修改失败！","",true);
		}
	}

}