<?php
namespace Backend\Controller;

use Backend\Controller\BackendController;
use Backend\Model\OrderModel;
use Backend\Model\ProductModel;
use Common\Respository\OrderRespository;

/**
 * 后台控制器模板
 * @author: duanbin
 * @时间: 2016年9月28日 下午5:06:01
 */
class OrderController extends BackendController{
	
	/**
	 * 订单列表页
	 * @时间: 2016年9月30日 下午3:30:32
	 * @author: duanbin
	 */
	public function index(){
		$order = new OrderModel();
		$respository = new OrderRespository($order);
		//表头，排序相关数据
		$th = $order->getSortable();
		//获取表头里面真正有排序的字段
		$sorted = $order->getSortableField($th);
		//未加排序前缀的表头
		$th_raw = array_keys($order->sortable);
		//获取筛选字段的需要的数据,筛选所需要的字段
		$search = $order->getFillData()->getSearchable();
		//获取需要展示的字段，列表的表头
		$field = implode(",",array_keys($order->sortable));
		//获取所有的数据
		$data = $respository->finder($field);
		//处理分页参数问题
		$current_page = empty(request()["p"]) ? 1 : request()["p"];
		$this->assign([
			"search" => $search,
			"th" => $th,"th_count" => count($th),    //表格列数
			"th_raw" => $th_raw,"sorted" => $sorted,    //真正可以排序的字段
			"data" => $data["data"],
			"sum_pages" => $data["sumPages"],
			"total" => $data["total"],
			"current_page" => $current_page,
			"per_page" => $data["perPage"],
			"pages" => $data["show"],
			"request" => request()
		]);
		$this->display();
	}

	/**
	 * 录入订单页面
	 * @时间: 2019年8月12日15:33:32
	 * @author: GuoPeng
	 */
	public function create(){
		$product = new ProductModel();
		$ptype = array(
			"host"=>7,
			"dedehost"=>15,
			"hkhost"=>8,
			"usahost"=>16,
			"cloudVirtual"=>17,
			"cloudspace"=>12,
			"endomain"=>9,
			"cndomain"=>10,
			"vps"=>1,
			"fastcloudvps"=>13,
//			"clouddb"=>22,
//			"cloudstorage"=>23,
//			"ssl"=>20,
//			"cloudsafe"=>24,
		);
		$ptypes = array(
			"host"=>"国内主机",
			"dedehost"=>"织梦主机",
			"hkhost"=>"香港主机",
			"usahost"=>"美国主机",
			"cloudVirtual"=>"云虚拟主机",
			"cloudspace"=>"云空间",
//			"domain"=>"域名",
			"endomain"=>"英文域名",
			"cndomain"=>"中文域名",
			"vps"=>"香港/特卖VPS",
			"fastcloudvps"=>"郑州快云VPS",
			"cloudserver"=>"快云服务器",
//			"clouddb"=>"快云数据库",
//			"cloudstorage"=>"快云存储",
//			"ssl"=>"SSL",
//			"cloudsafe"=>"云安全",
		);
		$where["product_type_id"] = array("in",$ptype);
		$where["type"] = array("eq",0);
		$where["_string"] = "FIND_IN_SET('2',stage)";
		$pnames = $product->where($where)->select();
		$ptype["cloudserver"] = 18;
		$pnames[] = $product->where(array("id"=>214))->find();
		$this->assign(["ptype" => $ptype,"ptypes" => $ptypes,"pnames" => $pnames]);
		$this->display();
	}
	
	/**
	 * 录入订单
	 * @时间: 2019年8月12日15:33:32
	 * @author: GuoPeng
	 */
	public function record(){
		$order = new OrderModel();
		$res = $order->record();
		if($res === false){
			$msg = $order->getError();
			$this->error($msg,"",true);
		}else{
			$msg = "录入订单成功！";
			$url = U("Order/index");
			$this->success($msg,$url,true);
		}
	}

	/**
	 * 更新订单页面
	 * @时间: 2016年10月14日 下午2:46:47
	 * @author: duanbin
	 */
	public function update(){
		$order = new OrderModel();
		$respository = new OrderRespository($order);
		$id = request()["id"] + 0;
		$entity = $respository->firstOrFalse($id);
		if(!$entity){
			$this->error("参数有误，没有该订单的相关信息！");
			die;
		}
		$fill_data = $order->getFillData()->fillData;
		$this->assign(["entity" => $entity,"extra" => $fill_data,"searchable" => $order->searchable,]);
		$this->display();
	}

	/**
	 * 更新订单
	 * @时间: 2016年10月14日 下午5:48:44
	 * @author: duanbin
	 */
	public function store(){
		$order = new OrderModel();
		$respository = new OrderRespository($order);
		//取参数
		$request = request(true);
		$id = $request["id"];
		unset($request["id"]);
		$data["state"] = $request["state"];
		$data["api_id"] = $request["api_id"];
		$data["beizhu"] = $request["beizhu"];
		//更新操作
		$res = $respository->update($data,$id);
		//返回结果
		if($res === false){
			$msg = $order->getError()."更新订单失败，请重试！";
			if(IS_AJAX){
				$this->error($msg,"",true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = "更新订单成功";
			$url = U("Order/index");
			if(IS_AJAX){
				$this->success($msg,$url,true);
			}else{
				$this->success($msg,$url);
			}
		}
	}

	/**
	 * 删除订单
	 * @时间: 2016年10月17日 下午2:39:35
	 * @author: duanbin
	 */
	public function disable(){
		$order = new OrderModel();
		//取参数
		$request = request();
		$id = $request["id"];
		//修改状态为禁用
		$data["state"] = 5;
		//更新操作
		$res = M("order")->where(["id" => ["eq",$id]])->setField($data);
		//返回结果
		if($res === false){
			$msg = $order->getError()."，删除订单失败，请重试！";
			if(IS_AJAX){
				$this->error($msg,"",true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = "删除订单成功";
			if(IS_AJAX){
				$this->success($msg,"",true);
			}else{
				$this->success($msg);
			}
		}
	}
	
	/**
	 * 订单详情页
	 * @时间: 2016年10月20日 上午11:45:20
	 * @author: duanbin
	 */
	public function details(){
		$order = new OrderModel();
		$respository = new OrderRespository($order);
		$id = request()["id"] + 0;
		$entity = $respository->firstOrFalse($id);
		if(!$entity){
			$this->error("参数有误，没有该订单的相关信息！");
			die;
		}
		$fill_data = $order->getFillData()->fillData;
		$this->assign(["entity" => $entity,"extra" => $fill_data,"searchable" => $order->searchable,]);
		$this->display();
	}
	
	/**
	 * 审核订单逻辑
	 * 仅限于虚拟主机和vps(有试用的产品)
	 * @时间: 2016年10月24日 下午3:03:29
	 * @author: duanbin
	 */
	public function review(){
		$order = new OrderModel();
		$id = request()["id"] + 0;
		$type = request()["type"] + 0;
		$res = $order->review($id,$type);
		$message = business_code($res);
		if($res === 0){
			$message = $order->getError();
		}
		//返回结果
		if($message == "成功"){
			$msg = "审核订单".$message;
			if(IS_AJAX){
				$this->success($msg,"",true);
			}else{
				$this->success($msg);
			}
		}else{
			$msg = $message;
			if(IS_AJAX){
				$this->error($msg,"",true);
			}else{
				$this->error($msg);
			}
		}
	}
	
	/**
	 * 订单退款
	 * @时间: 2018年2月27日15:15:59
	 * @author: Guopeng
	 */
	public function refund(){
		$order = new OrderModel();
		//更新操作
		$res = $order->refund();
		//返回结果
		if($res === false){
			$msg = $order->getError();
			if(IS_AJAX){
				$this->error($msg,"",true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = "退款成功！";
			if(IS_AJAX){
				$this->success($msg,"",true);
			}else{
				$this->success($msg);
			}
		}
	}

	/**
	 * 转让订单
	 * @时间: 2018年8月15日17:16:51
	 * @author: Guopeng
	 */
	public function assignment(){
		$order = new OrderModel();
		$respository = new OrderRespository($order);
		$request = request();
		$res = $respository->assignment($request);
		if($res === false){
			$msg = $order->getError()."请重试！";
			if(IS_AJAX){
				$this->error($msg,"",true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = "操作成功";
			if(IS_AJAX){
				$this->success($msg,"",true);
			}else{
				$this->success($msg);
			}
		}
	}

	/**
	 * 批量修改对应API
	 * @时间: 2019年7月8日16:29:49
	 * @author: GuoPeng
	 */
	public function batch_api(){
		$order = new OrderModel();
		$respository = new OrderRespository($order);
		$res = $respository->batch_api();
		if($res === false){
			$msg = $order->getError();
			if(IS_AJAX){
				$this->error($msg,"",true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = "修改成功";
			if(IS_AJAX){
				$this->success($msg,"",true);
			}else{
				$this->success($msg);
			}
		}
	}
	
}