<?php
namespace Backend\Controller;

use Backend\Controller\BackendController;
use Backend\Model\SysModel;
use Common\Model\ProductModel;

class SystemController extends BackendController{
	/**
	 * 初始化仓储和模型
	 * @时间: 2016年10月9日 下午4:49:54
	 * @author: duanbin
	 */
	public function _initialize(){
		parent::_initialize();
	}
	
	/**
	 * 网站设置的基本信息
	 * @时间: 2016年11月11日 上午11:19:26
	 * @author: duanbin
	 */
	public function configuration(){
		$basic_info = WebSiteConfig();
		$login_info = WebSiteConfig(6);
		$pay_info = WebSiteConfig(7);
		$custom_info = WebSiteConfig(9);
		//获取模板所在的绝对目录
		$pc_dirs = array();
		$mobile_dirs = array();
		$pc_dir_name =  "Application/Frontend/View";
		$mobile_dir_name =  "Application/Frontend/Mobile";
		if($pc_files = opendir($pc_dir_name)){
			while(($pc_file = readdir($pc_files)) !== false){
				if($pc_file !== "." && $pc_file !== ".."){
					if(is_dir($pc_dir_name."/".$pc_file)){
						$pc_dirs[] = $pc_file;
					}
				}
			}
			closedir($pc_dir_name);
		}
		if($mobile_files = opendir($mobile_dir_name)){
			while(($mobile_file = readdir($mobile_files)) !== false){
				if($mobile_file !== "." && $mobile_file !== ".."){
					if(is_dir($mobile_dir_name."/".$mobile_file)){
						$mobile_dirs[] = $mobile_file;
					}
				}
			}
			closedir($mobile_dir_name);
		}
		$custom_info["dirs"]["pc"] = $pc_dirs;
		$custom_info["dirs"]["mobile"] = $mobile_dirs;
		$domain = (isHTTPS() ? "https://" : "http://").$_SERVER["HTTP_HOST"];
		$this->assign([
			"basic_info" => $basic_info,
			"login_info" => $login_info,
			"pay_info" => $pay_info,
			"custom_info" => $custom_info,
			"domain" => $domain
		]);
		$this->display();
	}

	/**
	 * 网站配置项
	 * @时间: 2016年11月11日 下午2:59:58
	 * @author: duanbin
	 */
	public function configure(){
		$sys = new SysModel();
		$res = $sys->setup();
		//返回结果
		if($res === false){
			$msg = $sys->getError();
			if(IS_AJAX){
				$this->error($msg,"",true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = "操作成功";
			$url = U("System/configuration");
			if(IS_AJAX){
				$this->success($msg,$url,true);
			}else{
				$this->success($msg,$url);
			}
		}
	}

	/**
	 * 网站设置-API设置的基本信息
	 * @时间: 2019年4月3日14:13:39
	 * @author: GuoPeng
	 */
	public function form_api(){
		$api_info = WebSiteConfig(2);
		$this->assign(["api_info" => $api_info]);
		$this->display();
	}

	/**
	 * 网站设置-API设置方法
	 * @时间: 2019年4月3日14:13:39
	 * @author: GuoPeng
	 */
	public function setup_api(){
		$sys = new SysModel();
		$res = $sys->setup_api();
		//返回结果
		if($res === false){
			$msg = $sys->getError();
			$this->error($msg,"",true);
		}else{
			$msg = "操作成功！";
			$this->success($msg,"",true);
		}
	}

	/**
	 * 添加新API配置
	 * @date: 2018年3月5日11:17:17
	 * @author: Guopeng
	 */
	public function add_api(){
		$sys = new SysModel();
		$res = $sys->add_api(request());
		if($res === false){
			$msg = $sys->getError();
			if(IS_AJAX){
				$this->error($msg,"",true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = "添加API成功";
			if(IS_AJAX){
				$this->success($msg,"",true);
			}else{
				$this->success($msg,"");
			}
		}
	}

	/**
	 * 修改API接口地址
	 * @date: 2019年8月8日15:58:42
	 * @author: GuoPeng
	 */
	public function edit_api_url(){
		$sys = new SysModel();
		$res = $sys->edit_api_url();
		if($res){
			$this->success("API接口地址修改成功！","",true);
		}else{
			$msg = $sys->getError();
			$this->error($msg,"",true);
		}
	}

	/**
	 * 删除API配置
	 * @date: 2018年3月5日11:17:17
	 * @author: Guopeng
	 */
	public function del_api(){
		$sys = new SysModel();
		$res = $sys->del_api(request());
		if($res === false){
			$msg = $sys->getError();
			if(IS_AJAX){
				$this->error($msg,"",true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = "删除API成功";
			if(IS_AJAX){
				$this->success($msg,"",true);
			}else{
				$this->success($msg,"");
			}
		}
	}

	/**
	 * 网站设置-产品配置设置的基本信息
	 * @时间: 2019年4月3日14:13:39
	 * @author: GuoPeng
	 */
	public function form_product(){
		$product_info = WebSiteConfig(8);
		$this->assign(["product_info" => $product_info]);
		$this->display();
	}

	/**
	 * 网站设置-产品配置设置方法
	 * @时间: 2019年4月3日14:13:39
	 * @author: GuoPeng
	 */
	public function setup_product(){
		$sys = new SysModel();
		$res = $sys->setup_product();
		//返回结果
		if($res === false){
			$msg = $sys->getError();
			$this->error($msg,"",true);
		}else{
			$msg = "操作成功！";
			$this->success($msg,"",true);
		}
	}

	/**
	 * 邮箱配置页面
	 * @时间: 2016年11月11日 下午5:24:20
	 * @author: duanbin
	 */
	public function mail(){
		$mail_info = WebSiteConfig(SysModel::MAIL);
		$this->assign([
			"mail_info" => $mail_info,
		]);
		$this->display();
	}
	
	/**
	 * 邮件设置
	 * @时间: 2016年11月11日 下午5:35:16
	 * @author: duanbin
	 */
	public function mailSetup(){
		$sys = new SysModel();
		$res = $sys->setup();
		//返回结果
		if($res === false){
			$msg = $sys->getError();
			if(IS_AJAX){
				$this->error($msg,"",true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = "操作成功";
			$url = U("System/mail");
			if(IS_AJAX){
				$this->success($msg,$url,true);
			}else{
				$this->success($msg,$url);
			}
		}
	}

	/**
	* 测试邮件发送
	* @date: 2017年1月11日 上午10:16:54
	* @author: Lyubo
	*/
	public function mailtest(){
	    $sys = new SysModel();
	    $data = request();
	    $result = $sys->mailtest($data);
	    if($result["status"] === 0){
	        $res["status"] = 1;
	        $res["msg"] = "发送成功";
	        $this->ajaxReturn($res);
	    }else{
	        $res["status"] = 0;
	        $res["msg"] = "配置有误或邮箱不正确。".$result["message"];
	        $this->ajaxReturn($res);
	    }
	}

	/**
	 * 关于我们，支付方式介绍等页面的设置页面
	 * @时间: 2016年11月13日 下午4:01:25
	 * @author: duanbin
	 */
	public function pages(){
		$payment_info = WebSiteConfig(SysModel::PAYMENT_PAGE);
		$about_info = WebSiteConfig(SysModel::ABOUT);
		$top_bar = WebSiteConfig(SysModel::TOP_BAR);
		$end_bar = WebSiteConfig(SysModel::END_BAR);
		$this->assign([
			"payment_info" => $payment_info,
			"about_info" => $about_info,
			"end_bar" => each($end_bar),
			"top_bar" => each($top_bar)
		]);
		$this->display();
	}
	
	/**
	 * 关于我们，支付方式介绍等页面的设置
	 * @时间: 2016年11月13日 下午4:08:16
	 * @author: duanbin
	 */
	public function pagesSetup(){
		$sys = new SysModel();
		$res = $sys->setup();
		if($res === false){
			$msg = $sys->getError();
			if(IS_AJAX){
				$this->error($msg,"",true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = "操作成功";
			$url = U("System/pages");
			if(IS_AJAX){
				$this->success($msg,$url,true);
			}else{
				$this->success($msg,$url);
			}
		}
	}
	
	/**
	 * 网站seo优化页面
	 * @时间: 2016年11月13日 下午4:26:32
	 * @author: duanbin
	 */
	public function seo(){
		$sys = new SysModel();
		$where["sys_type"] = ["eq",SysModel::SEO];
		$seo_info = $sys->where($where)->select();
		$this->assign([
			"seo_info" => $seo_info
		]);
		$this->display();
	}
	
	/**
	 * 网站seo优化设置
	 * @时间: 2016年11月13日 下午4:28:10
	 * @author: duanbin
	 */
	public function seoSetup(){
		$sys = new SysModel();
		$res = $sys->setup();
		if($res === false){
			$msg = $sys->getError();
			if(IS_AJAX){
				$this->error($msg,"",true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = "操作成功";
			$url = U("System/seo");
			if(IS_AJAX){
				$this->success($msg,$url,true);
			}else{
				$this->success($msg,$url);
			}
		}
	}
	
	/**
	 * 常用操作，默认域名，和整站头部特殊公告等的设置页面
	 * @时间: 2016年11月14日 上午10:54:57
	 * @author: duanbin
	 */
	public function common(){
		$default_product = WebSiteConfig(SysModel::DEFAULT_DOMAIN);
		$default_domain = explode(",",$default_product["default_domain"]);
		$system_config = WebSiteConfig(13);
		$mail = json_decode($system_config["mail_content"],true);
		$product = new ProductModel();
		//获取所有的中文域名
		$chinese_domain = $product->getProductByProductTypeId(10);
		//获取所有的英文域名
		$others_domain = $product->getProductByProductTypeId(9);
		$this->assign([
			"mail" => $mail,
			"default_domain" => $default_domain,
			"chinese_domain" => $chinese_domain,
			"others_domain" => $others_domain,
		]);
		$re_domain = explode(",",$default_product["recommend_domain"]);
		$re_product = explode(",",$default_product["recommend_product"]);
		$ptype = array(
			"host"=>7,
			"dedehost"=>15,
			"hkhost"=>8,
			"usahost"=>16,
			"cloudVirtual"=>17,
			"cloudspace"=>12,
			"endomain"=>9,
			"cndomain"=>10,
			"vps"=>1,
			"fastcloudvps"=>13,
			"cloudserver"=>18,
			"clouddb"=>22,
			"cloudstorage"=>23,
			"ssl"=>20,
			"cloudsafe"=>24,
		);
		$where["product_type_id"] = array("in",$ptype);
		$where["type"] = array("eq",0);
		$where["product_state"] = array("eq",1);
		$where["_string"] = "FIND_IN_SET('2',stage)";
		$pnames = $product->where($where)->select();
		$this->assign(["re_domain" => $re_domain,"re_product" => $re_product,"pnames" => $pnames]);
		$this->display();
	}
	
	/**
	 * 常用操作，默认域名，和整站头部特殊公告等的设置
	 * @时间: 2016年11月14日 上午10:54:53
	 * @author: duanbin
	 */
	public function commonSetup(){
		$sys = new SysModel();
		$res = $sys->setup();
		//返回结果
		if($res === false){
			$msg = $sys->getError();
			if(IS_AJAX){
				$this->error($msg,"",true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = "操作成功";
			$url = U("System/seo");
			if(IS_AJAX){
				$this->success($msg,$url,true);
			}else{
				$this->success($msg,$url);
			}
		}
	}

	/**
	 * 定时任务配置
	 * @date: 2018年3月5日11:17:17
	 * @author: Guopeng
	 */
	public function timing(){
		$timing = WebSiteConfig(16);
		$ptype = explode(",",$timing["ptype"]);
		$ptypes = array(7=>"国内主机",8=>"香港主机",15=>"织梦主机",16=>"美国主机",17=>"云虚拟主机",12=>"云空间",10=>"域名",1=>"VPS",13=>"快云VPS",18=>"快云服务器",20=>"SSL",22=>"快云数据库",23=>"快云存储",24=>"抗D");
		$this->assign(["ptype" => $ptype,"ptypes" => $ptypes,"timing" => $timing]);
		$this->display();
	}

	/**
	 * 定时任务设置
	 * @date: 2018年3月5日11:17:17
	 * @author: Guopeng
	 */
	public function timing_task(){
		$sys = new SysModel();
		$res = $sys->setup_timing_task();
		if($res === false){
			$msg = $sys->getError();
			if(IS_AJAX){
				$this->error($msg,"",true);
			}else{
				$this->error($msg);
			}
		}else{
			$msg = "保存成功！";
			if(IS_AJAX){
				$this->success($msg,"",true);
			}else{
				$this->success($msg,"");
			}
		}
	}

	/**
	 * 网站设置-网站地图设置的基本信息
	 * @时间: 2019年4月3日14:13:39
	 * @author: GuoPeng
	 */
	public function sitemap(){
		$sitemap_info = WebSiteConfig(17);
		$this->assign(["sitemap_info" => $sitemap_info]);
		$this->display("form_sitemap");
	}

	/**
	 * 网站设置-网站地图设置方法
	 * @时间: 2019年4月3日14:13:39
	 * @author: GuoPeng
	 */
	public function setup_sitemap(){
		$model = new SysModel();
		$res = $model->setup_sitemap();
		//返回结果
		if($res === false){
			$msg = $model->getError();
			$this->error($msg,"",true);
		}else{
			$msg = "保存成功！";
			$this->success($msg,"",true);
		}
	}

	/**
	 * 网站设置-网站地图设置方法
	 * @时间: 2019年4月3日14:13:39
	 * @author: GuoPeng
	 */
	public function reset_sitemap(){
		$model = new SysModel();
		$res = $model->reset_sitemap();
		//返回结果
		if($res === false){
			$msg = $model->getError();
			$this->error($msg,"",true);
		}else{
			$msg = "保存成功！";
			$this->success($msg,"",true);
		}
	}

	/**
	 * 系统工具-关联登录接口设置
	 * @时间: 2019年9月2日16:58:56
	 * @author: GuoPeng
	 */
	public function unit_login(){
		$unit_login_info = WebSiteConfig(14);
		$this->assign(["info" => $unit_login_info]);
		$this->display();
	}

	/**
	 * 系统工具-关联登录接口设置
	 * @时间: 2019年9月2日16:58:56
	 * @author: GuoPeng
	 */
	public function unit_login_setup(){
		$sys = new SysModel();
		$res = $sys->unit_login_setup();
		//返回结果
		if($res === false){
			$msg = $sys->getError();
			$this->error($msg,"",true);
		}else{
			$msg = "操作成功！";
			$this->success($msg,"",true);
		}
	}
}