<?php
namespace Backend\Model;

use Backend\Model\BackendModel;

/**
 * 会员API模型类
 * @author: GuoPeng
 * @时间: 2019年8月2日16:45:20
 */
class ApiModel extends BackendModel{
	protected $trueTableName = "agent_member_api";

	//搜索条件字段
	public $searchable = [
		"state" => [
			"display_name" => "API状态",
			"html_type" => "select",
			"data" => ["0" => "失败","1" => "正常","2" => "审核中","3" => "禁用"]
		],
		"create_time" => [
			"display_name" => "创建时间",
			"html_type" => "date",
			"start_name" => "_start",
			"end_name" => "_end"
		],
		"key" => [
			"aid" => "Access_id",
			"user_id" => "会员ID",
			"login_name" => "登录名",
			"beizhu" => "备注"
		]
	];
	
	//排序字段
	public $sortable = [
		"id" => ["display_name" => "ID","sortable" => true],
		"user_id" => ["display_name" => "会员ID","sortable" => false],
		"login_name" => ["display_name" => "登陆名","sortable" => false],
		"aid" => ["display_name" => "Access_id","sortable" => false],
		"key" => ["display_name" => "Access_key","sortable" => false],
		"ip" => ["display_name" => "限制IP","sortable" => false],
		"state" => ["display_name" => "API状态","sortable" => false],
		"create_time" => ["display_name" => "创建时间","sortable" => true],
		"beizhu" => ["display_name" => "备注","sortable" => false]
	];
	
	/**
	 * 获取搜索条件所需要的数据,可以实现getFillData方法，将一些需要的数据复给$this->fill_data,例如本类的getFillData()方法
	 * @时间: 2019年8月5日14:32:33
	 * @author: GuoPeng
	 * @param array $fill_data
	 * @return null
	 */
	public function getSearchable($fill_data = []){
		if(empty($fill_data)){
			return $this->fillSearchable($this->fillData);
		}else{
			return $this->fillSearchable($fill_data);
		}
	}
	
	/**
	 * 获取搜索条件需要的数据
	 * @时间: 2019年8月5日14:32:33
	 * @author: GuoPeng
	 * @return $this
	 */
	public function getFillData(){
		/** 这里注意返回的一定是一个数组，并且数组的key一定是与searchable数组的key相同 */
		return $this;
	}

	/**
	 * 生成会员API
	 * @时间: 2019年8月5日14:32:33
	 * @author: GuoPeng
	 * @return bool|mixed
	 */
	public function create_api(){
		$data = request(true);
		$uid = $data["user_id"] + 0;
		$ip = $data["ip"];
		$state = 1;
		$beizhu = $data["beizhu"];
		$exists = M("member")->where(["user_id"=>["eq",$uid]])->find();
		if(empty($exists)){
			$this->error = "生成失败：该会员不存在！";
			return false;
		}
		if($exists["api_state"] != 1){
			$this->error = "生成失败：该会员不是代理会员！";
			return false;
		}
		if($exists["api_state"] == 2){
			$this->error = "生成失败：该会员API已生成！";
			return false;
		}
		if($exists["user_state"] != 1){
			$this->error = "生成失败：该会员状态异常！";
			return false;
		}
		$login_name = $exists["login_name"];
		$exists = $this->where(["user_id"=>["eq",$uid]])->find();
		if(!empty($exists)){
			M("Member")->where(["user_id"=>["eq",$uid]])->save(array("api_state"=>1));
			$this->error = "生成失败：该会员API已生成！";
			return false;
		}
		$aid = md5(md5($uid));
		$key = md5(md5($login_name.$uid));
		$save["user_id"] = $uid;
		$save["login_name"] = $login_name;
		$save["aid"] = $aid;
		$save["key"] = $key;
		$save["ip"] = $ip;
		$save["state"] = $state;
		$save["beizhu"] = $beizhu;
		$result = $this->add($save);
		if($result !== false){
			M("Member")->where(["user_id"=>["eq",$uid]])->save(array("api_state"=>2));
			return true;
		}else{
			$this->error = "生成失败：数据写入失败！";
			return false;
		}
	}

	/**
	 * 修改会员API信息
	 * @时间: 2019年8月5日14:32:33
	 * @author: GuoPeng
	 * @return bool|mixed
	 */
	public function edit_api(){
		$data = request(true);
		$id = $data["id"];
		$aid = $data["aid"];
		$key = $data["key"];
		$ip = $data["ip"];
		$state = $data["state"] + 0;
		$beizhu = $data["beizhu"];
		$exists = $this->where(["id"=>["eq",$id]])->find();
		if(empty($exists)){
			$this->error = "更新失败：该API信息不存在！";
			return false;
		}
		$save["aid"] = $aid;
		$save["key"] = $key;
		$save["ip"] = $ip;
		$save["state"] = $state;
		$save["beizhu"] = $beizhu;
		$result = $this->where(["id"=>["eq",$id]])->save($save);
		if($result !== false){
			return true;
		}else{
			$this->error = "更新失败：数据更新失败！";
			return false;
		}
	}
	
	/**********************************新增更新回调/开始***********************************/
	/**
	 * 插入数据之前的回调
	 * @时间: 2019年8月5日14:32:33
	 * @author: GuoPeng
	 * @param $data
	 * @param $options
	 * @return bool
	 */
	protected function _before_insert(&$data,$options){
		//不能为空的字段
		if(empty($data["aid"])){
			$this->error = "生成失败：Access_id不能为空！";
			return false;
		}
		if(empty($data["key"])){
			$this->error = "生成失败：Access_key不能为空！";
			return false;
		}
		//正则表达式
		$reg_access = "/[0-9a-z]{32}/";
		if(!preg_match($reg_access,$data["aid"])){
			$this->error = "生成失败：Access_id格式错误！";
			return false;
		}
		if(!preg_match($reg_access,$data["key"])){
			$this->error = "生成失败：Access_key格式错误！";
			return false;
		}
		//验证ip地址的正确性
		if (!empty($data['ip'])){
			$ips = explode(",",$data["ip"]);
			if(count($ips) > 3){
				$this->error = "更新失败：最多录入3个IP！";
				return false;
			}
			foreach($ips as $ip){
				if (!filter_var($ip, FILTER_VALIDATE_IP)){
					$this->error = "生成失败：IP地址格式错误！";
					return false;
				}
			}
		}
		if(!in_array($data["state"],array(0,1,2,3))){
			$this->error = "生成失败：状态参数错误！";
			return false;
		}
		//处理下备注说明的编码，统一转换成utf-8的编码，然后查看字数
		$beizhu = mb_convert_encoding($data["beizhu"],"utf-8");
		if(mb_strlen($beizhu,"utf-8") >= 100 * 3){
			$this->error = "生成失败：备注说明最多只有100个字！";
			return false;
		}
		//过滤xss脚本攻击
		$data["beizhu"] = clearXSS($data["beizhu"]);
		$data["create_time"] = date("Y-m-d H:i:s");
	}
	
	/**
	 * 插入成功后的回调
	 * @时间: 2019年8月5日14:32:33
	 * @author: GuoPeng
	 * @param $data
	 * @param $options
	 */
	protected function _after_insert($data,$options){}
	
	/**
	 * 更新数据之前做的操作
	 * @时间: 2019年8月5日14:32:33
	 * @author: GuoPeng
	 * @param $data
	 * @param $options
	 * @return bool
	 */
	protected function _before_update(&$data,$options){
		//不能为空的字段
		if(empty($data["aid"])){
			$this->error = "更新失败：Access_id不能为空！";
			return false;
		}
		if(empty($data["key"])){
			$this->error = "更新失败：Access_key不能为空！";
			return false;
		}
		//正则表达式
		$reg_access = "/[0-9a-z]{32}/";
		if(!preg_match($reg_access,$data["aid"])){
			$this->error = "更新失败：Access_id格式错误！";
			return false;
		}
		if(!preg_match($reg_access,$data["key"])){
			$this->error = "更新失败：Access_key格式错误！";
			return false;
		}
		//验证ip地址的正确性
		if (!empty($data['ip'])){
			$ips = explode(",",$data["ip"]);
			if(count($ips) > 3){
				$this->error = "更新失败：最多录入3个IP！";
				return false;
			}
			foreach($ips as $ip){
				if (!filter_var($ip, FILTER_VALIDATE_IP)){
					$this->error = "更新失败：IP地址格式错误！";
					return false;
				}
			}
		}
		if(!in_array($data["state"],array(0,1,2,3))){
			$this->error = "更新失败：状态参数错误！";
			return false;
		}
		//处理下备注说明的编码，统一转换成utf-8的编码，然后查看字数
		$beizhu = mb_convert_encoding($data["beizhu"],"utf-8");
		if(mb_strlen($beizhu,"utf-8") >= 100 * 3){
			$this->error = "更新失败：备注说明最多只有100个字！";
			return false;
		}
		//过滤xss脚本攻击
		$data["beizhu"] = clearXSS($data["beizhu"]);
	}
	
	/**
	 * 更新之后做的操作
	 * @时间: 2019年8月5日14:32:33
	 * @author: GuoPeng
	 * @param $data
	 * @param $options
	 */
	protected function _after_update($data,$options){}
	
	/**********************************新增更新回调/结束***********************************/
	/**
	 * 禁用会员API
	 * @时间: 2019年8月5日14:32:33
	 * @author: GuoPeng
	 * @return bool
	 */
	public function disable_api(){
		$request = request(true);
		$id = $request["id"];
		$data["state"] = 3;
		$res = M("member_api")->where(["id" => ["eq",$id]])->setField($data);
		if($res === false){
			$this->error = "禁用失败：数据更新失败！";
			return false;
		}else{
			return true;
		}
	}

	/**
	 * 启用会员API
	 * @时间: 2019年8月5日14:32:33
	 * @author: GuoPeng
	 * @return bool
	 */
	public function enable_api(){
		$request = request(true);
		$id = $request["id"];
		$data["state"] = 1;
		$res = M("member_api")->where(["id" => ["eq",$id]])->setField($data);
		if($res === false){
			$this->error = "启用失败：数据更新失败！";
			return false;
		}else{
			return true;
		}
	}

	/**
	 * 审核会员API
	 * @时间: 2019年8月5日14:32:33
	 * @author: GuoPeng
	 * @return bool
	 */
	public function review_api(){
		$request = request(true);
		$id = $request["id"];
		$data["state"] = 1;
		$res = M("member_api")->where(["id" => ["eq",$id]])->setField($data);
		if($res === false){
			$this->error = "审核失败：数据更新失败！";
			return false;
		}else{
			return true;
		}
	}

	/**
	 * 删除会员API
	 * @时间: 2019年8月5日14:32:33
	 * @author: GuoPeng
	 */
	public function delete_api(){
		$request = request(true);
		$id = $request["id"];
		$res = M("member_api")->where(["id" => ["eq",$id]])->delete();
		if($res === false){
			$this->error = "删除失败：数据删除失败！";
			return false;
		}else{
			return true;
		}
	}
}
