<?php
namespace Backend\Model;

use Backend\Model\BackendModel;

/**
 * 发票类
 * @author: GuoPeng
 * @时间: 2019年6月27日11:14:55
 */
class InvoiceModel extends BackendModel{
	//关联的表名
	protected $trueTableName = "agent_member_invoice";

	//搜索条件字段
	public $searchable = [
		"state" => [
			"display_name" => "状态",
			"html_type" => "select",
			"data" => [
				0 => "失败",
				1 => "正常",
				2 => "申请中"
			]
		],
		"create_time" => [
			"display_name" => "申请时间",
			"html_type" => "date",
			"start_name" => "_start",
			"end_name" => "_end"
		],
		"key" => [
			"id" => "序号",
			"payable" => "发票抬头"
		],
		"cost_type" => [
			"data" => array("其他","域名","虚拟主机","VPS","快云VPS","快云服务器","快云数据库","SSL证书","快云存储","抗D")
		],
		"fp_type" => [
			"data" => array(1=>"电子普通发票",2=>"增值税专用发票")
		],
		"kj_type" => [
			"data" => array(1=>"企业",2=>"个人")
		]
	];

	//排序字段
	public $sortable = [
		"id" => [
			"display_name" =>"序号",
			"sortable" => true
		],
		"user_id" => [
			"display_name" => "用户id",
			"sortable" => false
		],
		"login_name" => [
			"display_name" => "用户名",
			"sortable" => false
		],
		"fp_type" => [
			"display_name" => "发票类型",
			"sortable" => false
		],
		"kj_type" => [
			"display_name" => "开具类型",
			"sortable" => false
		],
		"payable" => [
			"display_name" =>"发票信息",
			"sortable" => false
		],
		"taxpayer_num" => [
			"display_name" =>"纳税人识别号",
			"sortable" => false
		],
		"comp_addr" => [
			"display_name" =>"注册地址",
			"sortable" => false
		],
		"comp_mobile" => [
			"display_name" =>"联系电话",
			"sortable" => false
		],
		"comp_bank" => [
			"display_name" =>"开户银行",
			"sortable" => false
		],
		"comp_bankcard" => [
			"display_name" =>"银行卡账号",
			"sortable" => false
		],
		"money" => [
			"display_name" =>"发票金额",
			"sortable" => false
		],
		"cost_type" => [
			"display_name" => "费用类别",
			"sortable" => false,
		],
		"name" => [
			"display_name" => "收件人信息",
			"sortable" => false
		],
		"phone" => [
			"display_name" => "收件人电话",
			"sortable" => false
		],
		"email" => [
			"display_name" => "电子邮件",
			"sortable" => false
		],
		"msg" => [
			"display_name" => "留言",
			"sortable" => false
		],
		"state" => [
			"display_name" => "状态",
			"sortable" => false
		],
		"create_time" => [
			"display_name" => "申请时间",
			"sortable" => true
		]
	];

	/**
	 * 完成发票申请
	 * @date: 2019年6月25日16:52:53
	 * @author: GuoPeng
	 */
	public function invoice_complete(){
		$data = request();
		$id = $data["id"] + 0;
		$info = $this->where(array("id"=>$id))->find();
		if(empty($info)){
			$this->error = "该申请记录不存在！";
			return false;
		}
		$res = $this->where(array("id"=>$id))->save(array("state"=>1));
		if($res !== false){
			return true;
		}else{
			$this->error = "该申请记录修改失败！";
			return false;
		}
	}

	/**
	 * 删除发票申请
	 * @date: 2019年6月25日16:52:53
	 * @author: GuoPeng
	 */
	public function invoice_erase(){
		$data = request();
		$id = $data["id"] + 0;
		$info = $this->where(array("id"=>$id))->find();
		if(empty($info)){
			$this->error = "删除失败：该申请记录不存在！";
			return false;
		}
		$res = $this->where(array("id"=>$id))->delete();
		if($res !== false){
			return true;
		}else{
			$this->error = "删除失败！";
			return false;
		}
	}

	/**
	 * 拒绝发票申请
	 * @date: 2019年6月25日16:52:53
	 * @author: GuoPeng
	 */
	public function invoice_refuse(){
		$data = request();
		$id = $data["id"] + 0;
		$beizhu = $data["beizhu"];
		$info = $this->where(array("id"=>$id))->find();
		if(empty($info)){
			$this->error = "拒绝失败：该申请记录不存在！";
			return false;
		}
		$res = $this->where(array("id"=>$id))->save(array("msg"=>$info["msg"]."-拒绝申请：{$beizhu}","state"=>0));
		if($res !== false){
			return true;
		}else{
			$this->error = "拒绝失败！";
			return false;
		}
	}

	/**
	 * 修改发票金额
	 * @date: 2019年6月25日16:52:53
	 * @author: GuoPeng
	 */
	public function invoice_update(){
		$data = request();
		$id = $data["id"] + 0;
		$money = $data["money"];
		if(!is_numeric($money) || $money <= 0){
			$this->error = "修改失败：发票金额错误！";
			return false;
		}
		$info = $this->where(array("id"=>$id))->find();
		if(empty($info)){
			$this->error = "修改失败：该申请记录不存在！";
			return false;
		}
		if($info["state"] != 2){
			$this->error = "修改失败：申请中的记录才能修改发票金额！";
			return false;
		}
		$res = $this->where(array("id"=>$id))->save(array("money"=>$money));
		if($res !== false){
			return true;
		}else{
			$this->error = "修改失败：数据更新失败！";
			return false;
		}
	}
	
	/**
	 * 获取搜索条件所需要的数据,可以实现getFillData方法,将一些需要的数据复给$this->fill_data,例如本类的getFillData()方法
	 * @时间: 2019年6月27日11:14:55
	 * @author: GuoPeng
	 * @param array $fill_data
	 * @return null
	 */
	public function getSearchable($fill_data = []){
		if (empty($fill_data)) {
			return $this->fillSearchable($this->fillData);
		}else {
			return $this->fillSearchable($fill_data);
		}
	}

	/**
	 * 获取搜索条件需要的数据;这里注意返回的一定是一个数组，并且数组的key一定是与searchable数组的key相同
	 * @时间: 2019年6月27日11:14:55
	 * @author: GuoPeng
	 * @return $this
	 */
	public function getFillData(){
		return $this;
	}
	/**********************************新增更新回调/开始***********************************/
	
	/**
	 * 插入数据之前的回调
	 * @时间: 2019年6月27日11:14:55
	 * @author: GuoPeng
	 * @param $data
	 * @param $options
	 */
	protected function _before_insert(&$data, $options){}
	
	/**
	 * 插入成功后的回调
	 * @时间: 2019年6月27日11:14:55
	 * @author: GuoPeng
	 * @param $data
	 * @param $options
	 */
	protected function _after_insert($data, $options){}
	
	/**
	 * 更新数据之前做的操作
	 * @时间: 2019年6月27日11:14:55
	 * @author: GuoPeng
	 * @param $data
	 * @param $options
	 */
	protected function _before_update(&$data, $options){}
	
	/**
	 * 更新之后做的操作
	 * @时间: 2019年6月27日11:14:55
	 * @author: GuoPeng
	 * @param $data
	 * @param $options
	 */
	protected function _after_update($data, $options){}
	/**********************************新增更新回调/结束***********************************/
}
