<?php
namespace Backend\Model;

use Backend\Model\BackendModel;
use Common\Aide\AgentAide;
use Common\Data\GiantAPIParamsData as GD;

/**
 * 产品模型类
 * @author: duanbin
 * @时间: 2016年10月9日 下午3:34:41
 */
class OrderModel extends BackendModel{
	
	//关联的表名
	protected $trueTableName = "agent_order";
	
	//搜索条件字段
	public $searchable = [
		'product_type' => [
			'display_name' => '产品类型',
			'html_type' => 'select',
			'data' => []
		],
		'area_code' => [
			'display_name' => '所属区域',
			'html_type' => 'select',
			'data' => []
		],
		'order_type' => [
			'display_name' => '类型',
			'html_type' => 'select',
			'data' => [
				'0' => '新增',
				'1' => '增值',
				'2' => '续费',
				'3' => '变更方案',
				'4' => '转正'
			]
		],
		'state' => [
			'display_name' => '状态',
			'html_type' => 'select',
			'data' => [
				'0' => '失败',
				'1' => '成功',
				'2' => '待处理',
				'3' => '处理中',
				'4' => '审核中',
				'5' => '已删除',
				'6' => '已付款',
				'7' => '退款中',
				'8' => '已退款'
			]
		],
		'free_trial' => [
			'display_name' => '购买/试用',
			'html_type' => 'select',
			'data' => [
				'0' => '购买',
				'1' => '试用'
			]
		],
		'key' => [
			'id' => '订单编号',
			'api_id' => 'API订单号',
			'product_name' => '产品名称',
			'note_appended' => '备注',
			'login_name' => '登录名'
		]
	];
	
	//排序字段
	public $sortable = [
		'id' => [
			'display_name' => '订单号',
			'sortable' => true
		],
		'login_name' => [
			'display_name' => '登录名',
			'sortable' => false
		],
		'user_id' => [
			'display_name' => '用户id',
			'sortable' => false
		],
		'order_type' => [
			'display_name' => '订单类型',
			'sortable' => false
		],
		'state' => [
			'display_name' => '状态',
			'sortable' => false
		],
		'product_type' => [
			'display_name' => '产品类型',
			'sortable' => false
		],
		'product_name' => [
			'display_name' => '产品名称',
			'sortable' => false
		],
		'free_trial' => [
			'display_name' => '是否试用',
			'sortable' => false
		],
		'order_time' => [
			'display_name' => '期限(月)',
			'sortable' => true
		],
		'create_time' => [
			'display_name' => '时间',
			'sortable' => true
		],
		'charge' => [
			'display_name' => '金额',
			'sortable' => true
		],
		'api_id' => [
			'display_name' => 'API订单号',
			'sortable' => false
		],
		'order_log' => [
			'display_name' => '详情',
			'sortable' => false
		],
		'access' => [
			'display_name' => '对应API',
			'sortable' => false
		]

	];
	
	/**
	 * 获取搜索条件所需要的数据,可以实现getFillData方法,将一些需要的数据复给$this->fill_data,例如本类的getFillData()方法
	 * @时间: 2016年10月11日 下午3:03:09
	 * @author: duanbin
	 * @param array $fill_data
	 * @return mixed|null
	 */
	public function getSearchable($fill_data = []){
		if(empty($fill_data)){
			return $this->fillSearchable($this->fillData);
		}else{
			return $this->fillSearchable($fill_data);
		}
	}
	
	/**
	 * 获取搜索条件需要的数据
	 * @时间: 2016年10月12日 下午2:54:05
	 * @author: duanbin
	 * @return $this
	 */
	public function getFillData(){
		/** 这里注意返回的一定是一个数组，并且数组的key一定是与searchable数组的key相同 */
		//产品分类数据
		$res = M("product_type")->field("id as k,type_name as v")->select();
		$_res = [];
		foreach($res as $k => $v){
			$_res[$v['k']] = $v['v'];
		}
		$fill_data['product_type'] = $_res;
		//区域数据
		$res = D('region')->field("region_code as k,region_name as v")->where(array("state"=>1))->select();
		$_res = [];
		foreach($res as $k => $v){
			$_res[$v['k']] = $v['v'];
		}
		$fill_data['area_code'] = $_res;
		//父类里继承来的属性
		$this->fillData = $fill_data;
		return $this;
	}
	
	/**
	 * 某些(试用)业务生效时，发送邮件通知用户的方法
	 * @时间: 2016年10月25日 下午4:21:21
	 * @author: duanbin
	 * @param $order_info
	 * @return array|bool
	 */
	public function mailNotice($order_info){
		//获取会员的信息
		$member_respository = new \Common\Respository\MemberRespository(M('Member'));
		$member_info = $member_respository->firstOrFalse(['user_id' => ['eq',$order_info['user_id']]]);
		//如果会员没有邮箱，则不发送邮件；
		if(empty($member_info['user_mail'])){
			$this->error = '该会员没有邮箱，无法发送邮件通知';
			return false;
		}
		//组装邮件内容
		$order_info['business_name'] = $order_info['product_name'];
		$mail_content = HTMLContentForEmail(3,$order_info,$member_info);
		//发送邮件
		$res = postOffice($member_info['user_mail'],$mail_content['subject'],$mail_content['body'],3);
		return $res;
	}
	
	/**
	 * 审核订单的业务逻辑
	 * 用于vps和虚拟主机的试用
	 * @时间: 2016年10月24日 下午3:06:57
	 * @author: duanbin
	 * @param $id
	 * @param $typt
	 * @return int
	 */
	public function review($id,$typt){
		//订单id
		$id += 0;
		$typt += 0;
		//先查看该订单是否是试用订单
		$order_info = $this->find($id);
		if(!$order_info['free_trial'] || $order_info ["state"] != 4){
			return -13;
		}
		//检查产品相关信息
		$product_info = D('Backend/Product')->getProductWithProductType($order_info['product_id']);
		if(!$product_info){
			return -2;
		}
		$ptype = $product_info['api_ptype'];
		$member_id = $order_info['user_id'];
		$order_id = $order_info['id'];
		if($typt == 0){
			$arr = array("state" => \Common\Data\StateData::PAYMENT_ORDER,"complete_time" => date('Y-m-d H:i:s'));
			$where["id"] = $order_id;
			if($this->where($where)->save($arr)){
				return -1;
			}else{
				$this->error = '服务器繁忙，操作失败，请重试';
				return 0;
			}
		}
		//引入景安api sdk;
		$api_access = $order_info["access"] + 0;
		$api_access = $api_access ? $api_access : 1;
		$agent = new AgentAide(1,$api_access);
		$transaction = $agent->servant;
		/*************************虚拟主机试用业务逻辑 star***************************/
		//如果是虚拟主机，那么可以并且是符合使用原则的
		//，那么就直接将订单状态改为6(已付款)，
		if($ptype == 'host' || $ptype == 'hkhost' || $ptype == GD::PTYPE_CLOUD_SPACE || $ptype == GD::PTYPE_USA_HOST || $ptype == GD::PTYPE_DEDE_HOST || $ptype == GD::PTYPE_CLOUD_VIRTUAL){
			//将该订单的状态改为6，已付款；
			$res = $this->where(['id' => ['eq',$id]])->setField('state',6);
			if($res === false){
				$this->error = '服务器繁忙，操作失败，请重试';
				return 0;
			}else{
				/*这里说明审核成功，发送邮件通知用户*/
				$res = $this->mailNotice($order_info);
				return -1;
			}
		}
		/*************************虚拟主机试用业务逻辑 end***************************/
		/*************************快云vps试用的审核逻辑 star**************************/
		if($ptype == GD::PTYPE_FAST_CLOUDVPS){
			$json = null;
			$m_fast_vps = new  \Common\Model\FastVpsBusinessModel();
			try{
				/*调用api接口，去主站获得相应的业务id*/
				$result = $transaction->get_business_info_order_id($product_info ["api_ptype"],$order_info ["api_id"]);
				api_log(session('user_id'),"ptype:".$ptype."--tid:".GD::TID_GET_BUSINESS_INFO."--did:".$order_info ["api_id"],$result,'获取审核状态');
				$json = json_decode($result);
			}catch(\Exception $e){
				return -9;
			}
			if($json == null){
				return -40;
			}
			if($json->code != 0){
				if($json->code == 1012){
					$note_appended = "会员编号:".$member_id."开通".$product_info['product_name']."订单编号：".$order_id;
					try{
						$result = $transaction->open($ptype,$order_info['api_id'],$order_info['system_type']);
						// 插入日志记录
						api_log($member_id,"ptype:".$ptype."--did:".$order_info['api_id']."--tid:".GD::TID_OPEN,$result,$note_appended);
					}catch(\Exception $e){
						api_log($member_id,"ptype:".$ptype."--did:".$order_info['api_id']."--tid:".GD::TID_OPEN,$e->getMessage(),$note_appended);
						return -9; // 调用接口失败
					}
					$xstr = json_decode($result,true);
					if($xstr['code'] == 0 && $xstr['code'] !== null){ // 开通成功
						$business_info = array("user_id" => $order_info['user_id'],"product_id" => $product_info['id'],"product_name" => $product_info['product_name'],"create_time" => date('Y-m-d H:i:s'),"service_time" => $order_info['order_time'],"free_trial" => $order_info['free_trial'],"login_name" => $order_info['login_name'],"system_type" => $order_info['system_type'],"access" => $api_access,"state" => \Common\Data\StateData::SUCCESS_ORDER,"note_appended" => $note_appended."执行成功","business_id" => $xstr['info']['bid'],"ip_address" => $xstr['info']['ip'],"system_user" => $xstr['info']['user'],"system_password" => $xstr['info']['pwd'],"open_time" => $xstr['info']['createDate'],"overdue_time" => $xstr['info']['overDate'],"remoteport" => $xstr['info']['remoteport'],"area_code" => $xstr['info']['areaCode']);
						// 添加快云vps业务表
						if($m_fast_vps->add($business_info)){
							$business_id = $m_fast_vps->getLastInsID();
							// 修改订单表订单标识，业务编号
							$arr = array("state" => \Common\Data\StateData::SUCCESS_ORDER,"business_id" => $xstr['info']['bid'],"ip_address" => $xstr['info']['ip'],"complete_time" => date('Y-m-d H:i:s'));
							$where["id"] = $order_id;
							if($this->where($where)->save($arr)){
								/*这里说明审核成功，发送邮件通知用户.发送开通邮件*/
								$result_inf['order_id'] = $order_id;
								$result_inf['ip_address'] = $xstr['info']['ip'];
								$result_inf['system_user'] = $xstr['info']['user'];
								$result_inf['system_password'] = $xstr['info']['pwd'];
								$result_inf['remoteport'] = $xstr['info']['remoteport'];
								$result_inf['createDate'] = $xstr['info']['createDate'];
								$result_inf['overDate'] = $xstr['info']['overDate'];
								$result_inf['product_name'] = $product_info['product_name'];
								business_sendMail('11',$result_inf,$member_id);
								return -1;
							}else{
								$dataarr['note_appended'] = $business_info['note_appended']."业务开通成功，订单状态修改失败";
								$up_where['id'] = array("eq",$business_id);
								$m_fast_vps->where($up_where)->save($dataarr);
								return -7;
							}
						}else{
							$this->error = '服务器繁忙，操作失败，请重试';
							return 0;
						}
					}else{
						if($xstr['code'] == 1026){
							$this->error = '操作失败，请在主站审核后再操作！';
							return 0;
						}
						return $xstr['code'];
					}
				}
				return $json->code;
			}
			/** 实例化快云vps业务模型类 */
			$add = $m_fast_vps->json_fast_vps_add($order_info,$product_info,$json);
			if($add == -1){
				return -15;
			}
			$this->where(['id' => ['eq',$id]])->save(['state' => 1,'business_id' => $add,'ip_address' => $json->info->ip]);
			/** 这里说明审核成功，发送邮件通知用户 */
			$res = $this->mailNotice($order_info);
			return -1;
		}
		/*************************快云vps试用的审核逻辑 end**************************/
		/***************************vps试用的审核逻辑 star**************************/
		if($ptype == GD::PTYPE_VPS){
			$m_vps = new \Common\Model\VpsBusinessModel();
			/*访问景安api，先获取业务编号*/
			$json = null;
			$business_id = null;
			// 获取业务编号
			try{
				$result = $transaction->get_business_id_order_id($product_info ["api_ptype"],$order_info ["api_id"]);
				$json = json_decode($result);
			}catch(\Exception $e){
				return -9;
			}
			if($json == null){
				return -40;
			}
			if($json->code != 0){
				if($json->code == 1012){
					$note_appended = "会员编号:".$member_id."开通".$product_info['product_name']."订单编号：".$order_id;
					try{
						$result = $transaction->open($ptype,$order_info['api_id'],$order_info['system_type']);
						// 插入日志记录
						api_log($member_id,"ptype:".$ptype."--did:".$order_info['api_id']."--tid:".GD::TID_OPEN,$result,$note_appended);
					}catch(\Exception $e){
						api_log($member_id,"ptype:".$ptype."--did:".$order_info['api_id']."--tid:".GD::TID_OPEN,$e->getMessage(),$note_appended);
						return -9; // 调用接口失败
					}
					$xstr = json_decode($result,true);
					if($xstr['code'] == 0 && $xstr['code'] !== null){ // 开通成功
						$business_info = array("user_id" => $order_info['user_id'],"product_id" => $product_info['id'],"product_name" => $product_info['product_name'],"create_time" => date('Y-m-d H:i:s'),"service_time" => $order_info['order_time'],"free_trial" => $order_info['free_trial'],"login_name" => $order_info['login_name'],"system_type" => $order_info['system_type'],"access" => $api_access,"state" => \Common\Data\StateData::SUCCESS_ORDER,"note_appended" => $note_appended."执行成功","business_id" => $xstr['info']['bid'],"ip_address" => $xstr['info']['ip'],"system_user" => $xstr['info']['user'],"system_password" => $xstr['info']['pwd'],"open_time" => $xstr['info']['createDate'],"overdue_time" => $xstr['info']['overDate'],"remoteport" => $xstr['info']['remoteport'],"area_code" => $xstr['info']['areaCode']);
						// 添加vps业务表
						if($m_vps->add($business_info)){
							$business_id = $m_vps->getLastInsID();
							// 修改订单表订单标识，业务编号
							$arr = array("state" => \Common\Data\StateData::SUCCESS_ORDER,"business_id" => $xstr['info']['bid'],"ip_address" => $xstr['info']['ip'],"complete_time" => date('Y-m-d H:i:s'));
							$where["id"] = $order_id;
							if($this->where($where)->save($arr)){
								/*这里说明审核成功，发送邮件通知用户.发送开通邮件*/
								$result_inf['order_id'] = $order_id;
								$result_inf['ip_address'] = $xstr['info']['ip'];
								$result_inf['system_user'] = $xstr['info']['user'];
								$result_inf['system_password'] = $xstr['info']['pwd'];
								$result_inf['remoteport'] = $xstr['info']['remoteport'];
								$result_inf['createDate'] = $xstr['info']['createDate'];
								$result_inf['overDate'] = $xstr['info']['overDate'];
								$result_inf['product_name'] = $product_info['product_name'];
								business_sendMail('11',$result_inf,$member_id);
								return -1;
							}else{
								$dataarr['note_appended'] = $business_info['note_appended']."业务开通成功，订单状态修改失败";
								$up_where['id'] = array("eq",$business_id);
								$m_vps->where($up_where)->save($dataarr);
								return -7;
							}
						}else{
							$this->error = '服务器繁忙，操作失败，请重试';
							return 0;
						}
					}else{
						if($xstr['code'] == 1026){
							$this->error = '操作失败，请在主站审核后再操作！';
							return 0;
						}
						return $xstr['code'];
					}
				}
				return $json->code;
			}
			$business_id = $json->info->bid;
			if(empty ($business_id)){
				return -41;
			}
			/*在获取通过业务编号，获取业务信息*/
			$json = null;
			try{
				$result = $transaction->get_business_info($product_info ["api_ptype"],$business_id);
				$json = json_decode($result);
			}catch(\Exception $e){
				return -9;
			}
			if($json == null){
				return -40;
			}
			if($json->code != 0){
				return $json->code;
			}
			/** 根据上面的业务信息，执行相应的业务 */
			// 执行相应业务
			$add = $m_vps->json_vps_add($order_info,$product_info,$json);
			if($add == -1){
				return -15;
			}
			// 更改订单状态
			$this->where(['id' => ['eq',$id]])->save(['state' => 1,'business_id' => $add,'ip_address' => $json->info->ip]);
			/** 这里说明审核成功，发送邮件通知用户 */
			$res = $this->mailNotice($order_info);
			return -1;
		}
		/***************************vps试用的审核逻辑 end**************************/
		//将该订单的状态改为6，已付款；
		$res = $this->where(['id' => ['eq',$id]])->setField('state',6);
		if($res === false){
			$this->error = '服务器繁忙，操作失败，请重试';
			return 0;
		}else{
			/*这里说明审核成功，发送邮件通知用户*/
			$res = $this->mailNotice($order_info);
			return -1;
		}
	}
	
	/**
	 * 订单退款
	 * @时间: 2018年2月27日15:15:59
	 * @author: Guopeng
	 */
	public function refund(){
		$request = request();
		$order_id = $request['id'];
		$order_info = $this->where(["id" => $order_id])->find();
		if(empty($order_info)){
			$this->error = "该订单不存在！";
			return false;
		}
		if($order_info["free_trial"] > 0){
			$this->error = "试用业务不能退款！";
			return false;
		}
		$product_info = M("product")->where(["id" => $order_info["product_id"]])->find();
		$user_id = $order_info["user_id"];
		$charge = $order_info["charge"] + 0;
		$user_info = M("member")->where(["user_id" => $user_id])->find();
		if(empty($user_info)){
			$this->error = "该会员不存在！";
			return false;
		}
		if($charge <= 0){
			$this->error = "价格错误！";
			return false;
		}
		$account_info = M("member_account")->where(["user_id" => $user_id])->find();
		$account_data["balance"] = $account_info["balance"] + $charge;
		$account_data["purchases"] = $account_info["purchases"] - $charge;
		$transactions_data["user_id"] = $user_id;
		$transactions_data["login_name"] = $user_info["login_name"];
		$transactions_data["order_id"] = $order_id;
		$transactions_data["account_money"] = $charge;
		$transactions_data["product_id"] = $order_info["product_id"];
		$transactions_data["type"] = 3;
		$transactions_data["create_time"] = current_date();
		$transactions_data["note_appended"] = "退款：[".$product_info["product_name"]."][退款金额".$charge."元]会员账户余额：".$account_data["balance"];
		$this->where(["id" => $order_id])->save(["state"=>7]);
		$res = M("member_account")->where(["user_id" => $user_id])->save($account_data);
		if($res === false){
			$this->where(["id" => $order_id])->save(["state"=>0,"note_appended"=>"退款失败","order_log"=>$order_info["order_log"]."--退款失败"]);
			$this->error = '退款失败，请重试！';
			return false;
		}else{
			$res = M("member_transactions")->add($transactions_data);
			if($res === false){
				$this->where(["id" => $order_id])->save(["state"=>8,"note_appended"=>"退款成功，退款记录生成失败","order_log"=>$order_info["order_log"]."--退款成功，退款记录生成失败"]);
				$this->error = '退款成功，退款记录生成失败！';
				return false;
			}else{
				$this->where(["id" => $order_id])->save(["state"=>8,"note_appended"=>"退款成功","order_log"=>$order_info["order_log"]."--退款成功"]);
				return true;
			}
		}
	}

	/**
	 * 录入订单
	 * @时间: 2019年8月13日11:43:13
	 * @author: GuoPeng
	 * @return bool
	 */
	public function record(){
		$data = request(true);
		$ptype = $data["ptype"] + 0;
		$pname = $data["pname"] + 0;
		$order_type = $data["order_type"] + 0;
		$state = $data["state"] + 0;
		$free_trial = $data["free_trial"] + 0;
		$order_time = $data["order_time"] + 0;
		$api_id = $data["api_id"] + 0;
		$charge = $data["charge"] + 0;
		$system_type = $data["system_type"] + 0;
		$business_id = $data["business_id"] + 0;
		$create_time = $data["create_time"];
		$note_appended = $data["note_appended"];
		$uid = $data["user_id"] + 0;
		$login_name = $data["login_name"];
		$access = $data["access"] + 0;
		$order_quantity = 1;
		$pinfo = M("product")->where(["id"=>$pname,"product_type_id"=>$ptype])->find();
		if(!$pinfo){
			$this->error = "录入订单失败：该产品不存在！";
			return false;
		}
		if($uid){
			$uinfo = M("member")->where(["user_id"=>$uid,"login_name"=>$login_name])->find();
			if(empty($uinfo)){
				$this->error = "录入订单失败：该会员不存在！";
				return false;
			}
		}else{
			$uid = -1;
			$login_name = "待转让会员";
		}
		$oinfo = $this->where(array("api_id"=>$api_id))->find();
		if($oinfo){
			$this->error = "录入订单失败：该api_id订单已存在！";
			return false;
		}
		if($order_type != 0){
			if($state == 4){
				$free_trial = 1;
			}else{
				$free_trial = 0;
			}
		}else{
			if($state == 4){
				$this->error = "录入订单失败：非新增类型订单不能是审核中状态！";
				return false;
			}
		}
		if($charge < 0){
			$charge = 0;
		}
		if($create_time == ""){
			$create_time = current_date();
		}
		$save["user_id"] = $uid;
		$save["login_name"] = $login_name;
		$save["order_type"] = $order_type;
		$save["state"] = $state;
		$save["product_type"] = $ptype;
		$save["product_id"] = $pname;
		$save["product_name"] = $pinfo["product_name"];
		$save["free_trial"] = $free_trial;
		$save["order_time"] = $order_time;
		$save["order_quantity"] = $order_quantity;
		$save["charge"] = $charge;
		$save["business_id"] = $business_id;
		$save["area_code"] = $pinfo["area_code"];
		$save["api_id"] = $api_id;
		$save["system_type"] = $system_type;
		$save["access"] = $access;
		$save["create_time"] = $create_time;
		$save["note_appended"] = $note_appended;
		$save["order_log"] = "手动录入订单";
		$res = $this->add($save);
		if($res === false){
			$this->error = '录入订单失败：请重试！';
			return false;
		}else{
			return true;
		}
	}
	
}
