<?php
namespace Common\Respository;

use Common\Respository\BusinessRespository;
use Common\Data\GiantAPIParamsData as GD;
use Common\Aide\AgentAide;

/**
 * 交易仓储类
 * 可选择实现orderExtra()，whereExtra()，fieldsExtra()方法，
 * 为了有连表的情况出现，额外设置别名
 * @author: duanbin
 * @时间: 2016年10月9日 下午3:50:29
 */
class CloudserverIpBusinessRespository extends BusinessRespository{
	/**
	 * 删除云服务器IP的方法
	 * @时间: 2016年11月4日 下午2:32:16
	 * @author: duanbin
	 * @param $id
	 * @return bool
	 */
	public function eraseCloudserverIpBusiness($id){
		return $this->erase($this->firstOrFalse(["id" => ['eq',$id]]),GD::PTYPE_CLOUD_SERVER,'cloudserver.ip');
	}

	/**
	 * 同步快云服务器ip的方法
	 * @时间: 2016年11月5日 下午6:17:01
	 * @author: duanbin
	 * @param $business_info
	 * @param string $belong_server
	 * @param string $attr
	 * @return bool
	 */
	public function CloudserverIpBusinessSynchronizing($business_info,$belong_server = '',$attr = "api_bid",$access = 0){
		//如果你传入的是id值那么就获取信息，如果你传入的是一条业务记录(数组),那么就不用再去取了
		$m_cloudserver_ip = $this->model();
		if(is_numeric($business_info) && !is_array($business_info)){
			//先获取本地业务信息
			$business_info_exists = $m_cloudserver_ip->where(["api_bid"=>['eq',$business_info]])->find();
			//如果不存在这条ip记录，那么就写进去
			if(empty($business_info_exists)){
				$api_config = WebSiteConfig(2);//获取网站配置
				$api_access = $api_config["api_access"] + 0;
				$api_access = $access ? $access : ($api_access ? $api_access : 1);
				list($business_info,$temp) = [[],$business_info];
				$business_info['access'] = $api_access;
				$business_info["api_bid"] = $temp;
				$business_info['user_id'] = -1;
				$add_id = $m_cloudserver_ip->add($business_info);
				$business_info["id"] = $add_id;
			}else{
				$business_info = $business_info_exists;
			}
		}
		$id = $business_info['id'];
		$api_access = $business_info["access"] + 0;
		$api_access = $api_access ? $api_access : 1;
		//调用api同步业务信息
		$result = $this->syncBusinessFromZZIDC($business_info,GD::PTYPE_CLOUD_SERVER,'cloudserver.ip');
		if(is_array($result) && !empty($result['json'])){
			// 业务信息
			$bus_info_ip = $result['json']['info'];
			$ipparms['product_name'] = '快云服务器IP';
			$ipparms['product_id'] = '227';
			$ipparms['api_bid'] = $bus_info_ip['ipywbh'];
			$ipparms['ipaddress'] = $bus_info_ip['ipdz'];
			$ipparms['bandwidth'] = $bus_info_ip['wldk'];
			$ipparms['create_time'] = $bus_info_ip['gmsj'];
			$ipparms['overdue_time'] = $bus_info_ip['dqsj'];
			$ipparms['buy_time'] = $bus_info_ip['gmqx'];
			$ipparms['area_code'] = $bus_info_ip['ip_areacode'];
			$ipparms['access'] = $api_access;
			if($bus_info_ip['dqsj'] > $bus_info_ip['gmsj']){
				$ipparms['state'] = 1;
			}else{
				$ipparms['state'] = 2;
			}
			$ipparms['belong_server'] = $belong_server;
			/** 这里去查询下快云服务器的信息，查看下里面是否有用户信息。 */
			$m_cloudserver = M('cloudserver_business');
			if(!empty($belong_server)){
				$cloudeserver_info = $m_cloudserver->where(['api_bid' => ['eq',$belong_server]])->find();
			}else{
				$cloudeserver_info = $m_cloudserver->where(['ip_bid' => ['eq',$ipparms['api_bid']]])->find();
			}
			$ipparms['user_id'] = !$cloudeserver_info['user_id'] ? (!$business_info['user_id'] ? '-1' : $business_info['user_id']) : $cloudeserver_info['user_id'];
			$ipparms['login_name'] = !$cloudeserver_info['login_name'] ? (!$business_info['login_name'] ? '待转让会员' : $business_info['login_name']) : $cloudeserver_info['login_name'];
			$ipparms['jiagou'] = $cloudeserver_info['jiagou'] ? $cloudeserver_info['jiagou'] : 2;
			$ipparms['belong_server'] = $cloudeserver_info['api_bid'];
			$update_res = $m_cloudserver_ip->where(["id" => ['eq',$id]])->save($ipparms);
			if($update_res === false){
				$m_cloudserver_ip->setError('服务器繁忙，同步失败，请重试');
				return false;
			}else{
				return true;
			}
		}else{
			if($business_info["sync_state"] == 0){
				$m_cloudserver_ip->where(["id" => ["eq",$id]])->delete();
				$m_cloudserver_ip->setError(business_code($result));
				return FALSE;
			}elseif($result == 1012){
				if(strtotime($business_info["overdue_time"]) <= time()){
					$parms["state"] = 3;
					$update_res = $m_cloudserver_ip->where(["id" => ["eq",$id]])->save($parms);
					if($update_res === false){
						$m_cloudserver_ip->setError("服务器繁忙，同步失败，请重试");
						return false;
					}else{
						$m_cloudserver_ip->setError("该业务已过期或不属于该会员！");
						return FALSE;
					}
				}else{
					$m_cloudserver_ip->setError(business_code($result));
					return FALSE;
				}
			}else{
				//说明同步调用api出错了,将错误结果返回出去
				$m_cloudserver_ip->setError(business_code($result));
				return FALSE;
			}
		}
	}

	/**
	 * 同步业务的主方法
	 * @时间: 2016年10月31日 下午5:35:32
	 * @author: duanbin
	 * @param $business_info
	 * @param $ptype
	 * @param string $pname
	 * @param int $tid
	 * @return array|int
	 */
	protected function syncBusinessFromZZIDC($business_info,$ptype,$pname = "",$tid = 18){
		$api_access = $business_info["access"] + 0;
		$api_access = $api_access ? $api_access : 1;
		//记录日志
		$log_message = "ptype:{$ptype}-bid:{$business_info["api_bid"]}-tid:{$tid}-access:{$api_access}";
		//引入景安api sdk;
		$agent = new AgentAide(1,$api_access);
		$transaction = $agent->servant;
		try{
			$result = $transaction->syncBusinessInfo($ptype,$business_info["api_bid"],$pname);
			api_log($business_info["user_id"],$log_message,$result,"同步云服务器IP业务信息");
			//解析JSON
			$json = json_decode($result,true);
		}catch(\Exception $e){
			api_log($business_info["user_id"],$log_message,$e->getMessage(),"同步云服务器IP业务信息失败");
			return -9;
		}
		if($json["code"] === null){
			return -9;
		}
		if($json["code"] != 0){
			return $json["code"];
		}
		//业务信息
		$bus_info = $json["info"];
		if(null == $bus_info){
			return -10;
		}
		$return = ["json"=>$json];
		return $return;
	}

	/**
	 * 批量同步业务信息
	 * @时间: 2019年4月17日15:11:46
	 * @author: GuoPeng
	 * @param $ptype
	 * @param $flag
	 * @param $pname
	 * @param $atype
	 * @return array|bool
	 */
	public function syncBatch($ptype,$flag,$pname="",$atype="com",$time=0){
		if($flag == "diff"){
			$api_config = WebSiteConfig(2);//获取网站配置
			if($atype == "hk"){
				if($api_config["api_hk"] != 1){
					$this->model()->setError("国际站API配置未开启！");
					return FALSE;
				}
			}
			$res = $this->syncBatchBusinessFromZZIDC($ptype,$time,$pname,"api_bid",$atype);
		}elseif($flag == "all"){
			$res = $this->getBusinessFromSelf("api_bid");
		}elseif($flag == "batch"){
			$request = request();
			$ids = explode(",",$request["ids"]);
			$where["id"] = array("in",$ids);
			$res = $this->getBusinessFromSelf("api_bid",$where);
		}
		if(is_array($res)){
			return $res;
		}else{
			//说明同步调用api出错了,将错误结果返回出去
			$this->model()->setError(business_code($res));
			return FALSE;
		}
	}

	/**
	 * 批量同步业务的核心方法 差异同步业务的主方法
	 * @时间: 2019年4月17日15:11:46
	 * @author: GuoPeng
	 * @param $ptype
	 * @param int $time
	 * @param string $pname
	 * @param string $bid_field
	 * @return array
	 */
	protected function syncBatchBusinessFromZZIDC($ptype,$time = 0,$pname = "",$bid_field = "business_id",$atype="com"){
		$api_config = WebSiteConfig(2);//获取网站配置
		$api_access = $api_config["api_access"] + 0;
		$api_access = $api_access ? $api_access : 1;
		if($atype == "hk"){
			$api_access = $api_config["api_hk_access"] + 0;
			$api_access = $api_access ? $api_access : 6;
		}
		//引入景安api sdk;
		$agent = new AgentAide(1,$api_access);
		$transaction = $agent->servant;
		$tid = 20;
		$log_message = "ptype:{$ptype}-tid:{$tid}-yid:{$time}-pname:{$pname}-access:{$api_access}";
		try{
			$flag["code"] = -1;
			$result = $transaction->syscAllBusinessInfo($ptype,$tid,$time,$pname);
			// 记录日志
			api_log("管理员",$log_message,$result,"批量同步云服务器业务信息");
			// 解析JSON
			$json = json_decode($result,true);
		}catch(\Exception $e){
			api_log("管理员",$log_message,$e->getMessage(),"批量同步云服务器业务信息失败");
			return -9;
		}
		// 业务信息
		if($json["code"] === null){
			return -9;
		}
		if($json["code"] == 5034){
			return array();
		}
		if($json["code"] != 0){
			return $json["code"];
		}
		$bus_info = $json["info"];
		if(empty($bus_info)){
			return -10;
		}
		$api_bids = explode(",",$bus_info);
		//保存需要同步的业务的id
		$data = [];
		foreach($api_bids as $k => $api_bid){
			if(!empty($api_bid)){
				$business_exist = $this->firstOrFalse([$bid_field => ["eq",$api_bid]]);
				//如果业务不存在，那么就写入到数据库里
				if(empty($business_exist)){
					//组装数据
					$parms["user_id"] = -1;
					$parms["login_name"] = "待转让";
					$parms["product_name"] = "未同步业务";
					$parms["product_id"] = 0;
					$parms["state"] = 1;
					$parms["api_bid"] = $api_bid;
					$parms["sync_state"] = 0;
					$parms["access"] = $api_access;
					$parms["create_time"] = date("Y-m-d H:i:s");
					$parms["overdue_time"] = date("Y-m-d H:i:s");
					$res = $this->model()->add($parms);
					if($res !== false){
						// 保存api_bid
						$data[] = $api_bid;
					}
				}else{
					$this->model()->where(["id" => $business_exist["id"]])->save(["access" => $api_access]);
				}
			}
		}
		return $data;
	}
	
}