<?php
namespace Common\Respository;

use Common\Respository\BaseRespository;

/**
 * 发票仓储类
 * 可选择实现orderExtra()，whereExtra()，fieldsExtra()方法，
 * 为了有连表的情况出现，额外设置别名
 * @author: GuoPeng
 * @时间: 2019年6月27日11:14:55
 * @version: 1.0
 */
class InvoiceRespository extends BaseRespository{

	/**
	 * 扩充查询字段，在连表的情况下有别名使用
	 * @时间: 2019年6月27日11:14:55
	 * @author: GuoPeng
	 * @param $fields
	 * @return array
	 */
	protected function fieldsExtra($fields){
		if (is_string($fields)){
			$fields = explode(",", $fields);
		}
		foreach ($fields as $k => $filed){
			if($filed == 'user_id'){
				$fields[$k] = "m.{$filed} as {$filed}";
			}elseif($filed == 'login_name'){
				$fields[$k] = "m.{$filed} as {$filed}";
			}else{
				$fields[$k] = $this->alias.".{$filed} as {$filed}";
			}
		}
		return $fields;
	}

	/**
	 * 返回一个join数组,连表查询时，请实现此方法
	 * @时间: 2019年6月27日11:14:55
	 * @author: GuoPeng
	 * @return array
	 */
	protected function joinsExtra(){
		return ['left join '.$this->table_prefix.'member as m on '.$this->alias.'.user_id = m.user_id'];
	}

	/**
	 * 额外的扩充条件，这里要增加一项
	 * @时间: 2019年6月27日11:14:55
	 * @author: GuoPeng
	 * @param $where
	 * @param $request
	 * @return array
	 */
	protected function whereExtra($where, $request){
		$_where = [];
		/** 这里是为了会员详情页面跳转增加的参数 */
		/*if (!empty($request["user_id"])){
			$_where[$this->alias.".user_id"] = $request["user_id"];
		}*/
		foreach($where as $k => $v){
			if($k == 'user_id'){
				$_where['m.user_id'] = $v;
			}elseif($k == 'login_name'){
				$_where['m.login_name'] = $v;
			}else{
				$_where[$this->alias.'.'.$k] = $v;
			}
		}
		return $_where;
	}

	/**
	 * 额外的扩充排序，这里要增加一项
	 * @时间: 2019年6月27日11:14:55
	 * @author: GuoPeng
	 * @param $order
	 * @param $request
	 * @return string
	 */
	public function orderExtra($order,$request){
		//增加默认排序规则
		if(empty($order)){
			//到期时间倒序
			$order = $this->alias.".create_time DESC";
		}
		return $order;
	}

	/**
	 * 业务统计方法，统计出各个分类的总数等
	 * @时间: 2019年6月27日11:14:55
	 * @author: GuoPeng
	 * @param $field
	 * @return array
	 */
	public function counter($field){
		$counter = [];
		/** 总记录数 */
		$counter["total"] = $this->queryBuilder($field,[]);
		/** 成功发票 */
		$where["state"] = ["eq",1];
		$counter["successful"] = $this->queryBuilder($field,$where);
		/** 未开具发票 */
		$where["state"] = ["eq",2];
		$counter["apply"] = $this->queryBuilder($field,$where);
		/** 失败发票 */
		$where["state"] = ["eq",0];
		$counter["failed"] = $this->queryBuilder($field,$where);
		return $counter;
	}
}