<?php
namespace Frontend\Model;

use Think\Model;

/**
 * 会员API模型类
 * @author: GuoPeng
 * @时间: 2019年8月6日14:33:22
 */
class ApiModel extends Model{
	protected $trueTableName = "agent_member_api";

	/**
	 * 会员API-获取信息
	 * @时间: 2019年8月6日14:33:22
	 * @author: GuoPeng
	 */
	public function get_member_api(){
		$uid = session("user_id");
		$info = $this->where(["user_id" => ["eq",$uid]])->find();
		return $info;
	}

	/**
	 * 会员API-申请
	 * @时间: 2019年8月7日17:41:06
	 * @author: GuoPeng
	 */
	public function apply_api(){
		$uid = session("user_id");
		$data = request(true);
		$ip = $data["ip"];
		$member = new MemberModel();
		$exists = $member->where(["user_id"=>["eq",$uid]])->find();
		if(empty($exists)){
			$return["state"] = false;
			$return["msg"] = "申请API失败：该会员不存在！";
			return $return;
		}
		if($exists["api_state"] == 2){
			$return["state"] = false;
			$return["msg"] = "申请API失败：您已经申请过API，不得重复申请！";
			return $return;
		}
		if($exists["api_state"] != 1){
			$return["state"] = false;
			$return["msg"] = "申请API失败：您不是代理会员！";
			return $return;
		}
		if($exists["user_state"] != 1){
			$return["state"] = false;
			$return["msg"] = "申请API失败：该会员状态异常！";
			return $return;
		}
		$info = $this->where(["user_id"=>$uid])->find();
		if($info){
			$member->where(["user_id"=>["eq",$uid]])->save(array("api_state"=>2));
			$return["state"] = false;
			$return["msg"] = "申请API失败：您已经申请过API，不得重复申请！";
			return $return;
		}
		if(!filter_var($ip, FILTER_VALIDATE_IP)){
			$return["state"] = false;
			$return["msg"] = "申请API失败：IP地址格式错误！";
			return $return;
		}
		$login_name = $exists["login_name"];
		$aid = md5(md5($uid));
		$key = md5(md5($login_name.$uid));
		$save["user_id"] = $uid;
		$save["login_name"] = $login_name;
		$save["aid"] = $aid;
		$save["key"] = $key;
		$save["ip"] = $ip;
		$save["ip_state"] = 0;
		$save["state"] = 2;
		$save["create_time"] = date("Y-m-d H:i:s");
		$res = $this->add($save);
		if($res === false){
			$return["state"] = false;
			$return["msg"] = "申请API失败：数据生成失败！";
			return $return;
		}else{
			$return["state"] = true;
			$return["msg"] = "申请API成功，请联系客服审核！";
			return $return;
		}
	}

	/**
	 * 会员API-重新生成密钥
	 * @date: 2019年8月7日17:41:06
	 * @author: GuoPeng
	 * @return bool|mixed
	 */
	public function reset_api_key(){
		$uid = session("user_id");
		$data = request(true);
		$id = $data["id"];
		$info = $this->where(["id"=>["eq",$id]])->find();
		if(empty($info)){
			$return["state"] = false;
			$return["msg"] = "重新生成密钥失败：该API信息不存在！";
			return $return;
		}
		if($info["user_id"] != $uid){
			$return["state"] = false;
			$return["msg"] = "重新生成密钥失败：该API不属于该会员！";
			return $return;
		}
		$key = md5(md5($this->get_rand().$uid));
		$save["key"] = $key;
		$result = $this->where(["id"=>["eq",$id]])->save($save);
		if($result !== false){
			$return["state"] = true;
			$return["msg"] = "重新生成密钥成功！";
			return $return;
		}else{
			$return["state"] = false;
			$return["msg"] = "重新生成密钥失败：数据更新失败！";
			return $return;
		}
	}

	/**
	 * 会员API-修改调用IP
	 * @date: 2019年8月7日17:41:06
	 * @author: GuoPeng
	 */
	public function modify_api_ip(){
		$uid = session("user_id");
		$data = request(true);
		$id = $data["id"];
		$info = $this->where(["id"=>["eq",$id]])->find();
		if(empty($info)){
			$return["state"] = false;
			$return["msg"] = "修改调用IP失败：该API信息不存在！";
			return $return;
		}
		if($info["user_id"] != $uid){
			$return["state"] = false;
			$return["msg"] = "修改调用IP失败：该API不属于该会员！";
			return $return;
		}
		$ips = explode("\n",$data["ip"]);
		foreach($ips as $key=>$ip){
			if($ip === ""){
				unset($ips[$key]);
			}elseif(!filter_var($ip, FILTER_VALIDATE_IP)){
				$return["state"] = false;
				$return["msg"] = "修改调用IP失败：IP地址格式错误！";
				return $return;
			}
		}
		if(count($ips) > 3){
			$return["state"] = false;
			$return["msg"] = "修改调用IP失败：最多录入3个IP！";
			return $return;
		}
		$ip = implode(",",$ips);
		$save["ip"] = $ip;
		$result = $this->where(["id"=>["eq",$id]])->save($save);
		if($result !== false){
			$return["state"] = true;
			$return["msg"] = "修改调用IP成功，确认调用IP是否正确，以便API接口能正常调用！";
			return $return;
		}else{
			$return["state"] = false;
			$return["msg"] = "修改调用IP失败：数据更新失败！";
			return $return;
		}
	}

	/**
	 * 会员API-开启/取消调用IP限制
	 * @date: 2019年8月7日17:41:06
	 * @author: GuoPeng
	 */
	public function operation_api_ip(){
		$uid = session("user_id");
		$data = request(true);
		$id = $data["id"];
		$ip_state = $data["ip_state"] + 0;
		$ms = "开启";
		if($ip_state != 1){
			$ip_state = 0;
			$ms = "取消";
		}
		$info = $this->where(["id"=>["eq",$id]])->find();
		if(empty($info)){
			$return["state"] = false;
			$return["msg"] = "{$ms}调用IP限制失败：该API信息不存在！";
			return $return;
		}
		if($info["user_id"] != $uid){
			$return["state"] = false;
			$return["msg"] = "{$ms}调用IP限制失败：该API不属于该会员！";
			return $return;
		}
		$save["ip_state"] = $ip_state;
		$result = $this->where(["id"=>["eq",$id]])->save($save);
		if($result !== false){
			$return["state"] = true;
			$return["msg"] = "{$ms}调用IP限制成功，确认调用IP是否正确，以便API接口能正常调用！";
			if($ip_state != 1){
				$return["msg"] = "{$ms}调用IP限制成功！";
			}
			return $return;
		}else{
			$return["state"] = false;
			$return["msg"] = "{$ms}调用IP限制失败：数据更新失败！";
			return $return;
		}
	}

	/**
	 * 生成随机字符串
	 * @date: 2019年8月7日17:41:06
	 * @author: GuoPeng
	 * @param int $length
	 * @return string
	 */
	private function get_rand($length = 6){
		$chars = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
		$password = "";
		for($i = 0;$i < $length;$i++){
			$password .= $chars[mt_rand(0,strlen($chars) - 1)];
		}
		return $password;
	}
}
