<?php
namespace Frontend\Model;

use Common\Data\StateData as SD;
use Common\Model\CertifyLogModel;
use Frontend\Model\BusinessModel;
use Common\Aide\AgentAide;
use Common\Data\GiantAPIParamsData as GD;

class DomainModel extends BusinessModel{
	protected $trueTableName = 'agent_domain_business';

	public function conver_par(){
		$date = request();
		$where["bs.user_id"] = array("eq",session("user_id"));
		if(!empty($date['select'])){
			$select = clearXSS($date['select']);
			$map['bs.api_bid'] = array("like","%$select%");
			$map['_logic'] = 'OR';
			$map['bs.domain_name'] = array("like","%$select%");
			$map['_logic'] = 'OR';
			$map["bs.beizhu"] = array("like","%$select%");
			$where['_complex'] = $map;
		}
		return $where;
	}

	/**
	 * 跳转中国数据控制面板
	 * @date: 2016年10月29日 下午2:52:54
	 * @author: Lyubo
	 * @return int|mixed
	 */
	public function domain_panel(){
		$data = request();
		$api_bid = $data["business_id"];
		$user_id = session("user_id");
		$info = $this->get_api_bid_one($api_bid);
		$api_access = $info["access"] + 0;
		$api_access = $api_access ? $api_access : 1;
		$agent = new AgentAide(1,$api_access);
		$transaction = $agent->servant;
		if($info){
			try{
				$result = $transaction->domainskip($api_bid);
				$log_message = "ptype:".GD::PTYPE_DOMAIN.'||tid=15';
				api_log($user_id,$log_message,$result,"跳转中国数据控制面板");
				$json = json_decode($result,true);
			}catch(\Exception $e){
				$log_message = "ptype:".GD::PTYPE_DOMAIN.'||tid=15';
				if(empty($result)){
					$result = $e->getMessage();
				}
				api_log($user_id,$log_message,$result,"跳转中国数据控制面板失败");
				return ["code"=>-9];
			}
			return $json;
		}else{
			return ["code"=>-1];
		}
	}

	/**
	 * 域名产品信息
	 * @date: 2016年11月20日 下午1:54:22
	 * @author: Lyubo
	 * @return: array
	 */
	public function domain_product(){
		$product = new ProductModel();
		$product_type_list = $product->get_type_list('4');//4为域名的顶级分类
		foreach($product_type_list as $ptl){
			$product_list[$ptl['api_ptype']] = $product->domain_info($ptl ['id']);
		}
		return $product_list;
	}

	/**
	 * 默认选中域名  获取默认域名信息
	 * @date: 2016年11月20日 下午4:52:42
	 * @author: Lyubo
	 * @return mixed
	 */
	public function get_default_domain(){
		$product = new ProductModel();
		// 获取信息
		$result = WebSiteConfig(SD::SYS_DEFAULT_DOMAIN);
		// 以逗号分隔
		$value = explode(",",$result["default_domain"]);
		foreach($value as $key => $val){
			$default_domain[$key] = $product->get_product($val);
		}
		return $default_domain;
	}

	/**
	 * 域名查询
	 * @date: 2018年12月28日14:29:56
	 * @author: Guopeng
	 * @param bool $ajax 是否ajax提交
	 * @return mixed
	 */
	public function domain_query(){
		$data = request(true);
		$product = new ProductModel();
		$domain = $data["domain_name"];
		$domain_id = $data["product_id"]+0;
		$domain_product = $product->get_product($domain_id);
		if(!$domain_product){
			$return["msg"] = "产品查询失败！";
			$return["status"] = false;
			return $return;
		}
		$domain_type = $domain_product["api_ptype"];
		$product_type = $domain_product["product_type_id"];
		$suffix = [];
		$where['id'] = ['eq',$domain_id];
		$where['product_type_id'] = ['eq',$product_type];
		$where["_string"] = "FIND_IN_SET('2',stage)";
		$check_suffix_info = $product->where($where)->find();
		if(empty($check_suffix_info)){
			$return["msg"] = business_code(-2);
			$return["status"] = false;
			return $return;
		}
		$id = $check_suffix_info["id"];
		$product_list = $product->product_by_id($id,$domain_type);
		if(!is_array($product_list)){
			$return["msg"] = business_code(-2);
			$return["status"] = false;
			return $return;
		}
		$suffix[] = $product_list["product_name"];
		$api_config = WebSiteConfig(2);//获取网站配置
		$api_access = $api_config["api_access"] + 0;
		$api_access = $api_access ? $api_access : 1;
		$agent = new AgentAide(1,$api_access);
		$transaction = $agent->servant;
		try{
			$result = $transaction->new_domain_quary($domain,$suffix);
			api_log(-1,$domain."域名查询",$result,"查询成功");
		}catch(\Exception $e){
			api_log(-1,$domain."域名查询",$e->getMessage(),"查询失败");
			$return["msg"] = business_code(-9);
			$return["status"] = false;
			return $return;
		}
		$xstr = json_decode($result,true);
		if($xstr["code"] != 0 || $xstr["code"] === null){
			$return["msg"] = business_code($xstr["code"]);
			$return["status"] = false;
			return $return;
		}
		//可以注册列表
		$yesList = $xstr["info"]["yesList"];
		//查询失败列表
		$failList = $xstr["info"]["failList"];
		//不可注册列表
		$noList = $xstr["info"]["noList"];
		//修改状态
		unset($product_list['config']);
		$product_name = $product_list["product_name"];
		//可以注册
		if(in_array($product_name,$yesList)){
			$product_list["is_reg"] = 1;
		}
		//查询失败
		if(in_array($product_name,$failList)){
			$product_list["is_reg"] = 0;
		}
		//不可以注册
		if(in_array($product_name,$noList)){
			$product_list["is_reg"] = 2;
		}
		$product_list["queryfreedomain"] = "no";
		if($product_name === ".top"){
			if(!empty($xstr["info"]["queryfreedomain"][$domain.$product_name])){
				if(isMobile() != "phone"){
					$price["year"] = 1;
					$price["price"] = $xstr["info"]["queryfreedomain"][$domain.$product_name];
					$domain_price[] = $price;
				}else{
					$domain_price = $xstr["info"]["queryfreedomain"][$domain.$product_name];
				}
				$product_list["queryfreedomain"] = "yes";
				$price_list = array();
				foreach($product_list["price_list"] as $k=>$v){
					if($v["api_type"] == 5){
						$price_list = $v;
					}
				}
				if($price_list){
					$price_list["product_price"] = $domain_price;
					$price_list["xishu"] = false;
					$price_list["wanwang"] = false;
					$product_list["price_list"] = array();
					$product_list["price_list"]["zs"] = $price_list;
					$product_list["is_reg"] = 1;
					$product_list["domain_price"] = $price["price"];
				}else{
					$product_list["queryfreedomain"] = "no";
				}
			}
		}
		$product_list["domain_name"] = $domain;
		$product_list["div_id"] = $domain.str_replace(".","",str_replace(".","",$product_name));
		$return["info"] = $product_list;
		$return["status"] = true;
		return $return;
	}

	/**
	 * 显示域名注册
	 * @date: 2016年11月27日 上午11:11:48
	 * @author: Lyubo
	 * @return int|mixed
	 */
	public function show_domain_register(){
		$member_id = session('user_id');
		$data = request(true);
		$product = new ProductModel();
		$api_ptype = $data["api_ptype"];
		if($api_ptype == "cndomain"){
			$product_type_id = 10;
		}else{
			$product_type_id = 9;
		}
		if($data['product_id'] == 273 && $data["queryfreedomain"] === "yes"){
			$price_list["price"] = number_format(ceil($data["domain_price"]),2,".","");
			$price_list["year"] = 1;
		}else{
			$discount = 1;
			if(session('?user_id')){
				$user = new MemberModel();
				$user_id = session('user_id');
				$user_level = $user->get_user_level($user_id,$product_type_id);
				if($user_level["discount"] > 0){
					$discount = $user_level["discount"];
				}
			}
			if(isMobile() == "phone"){
				$zs = 1;
				$api_type = 5;
				$zs_buy_price = $product->get_product_price_list($data['product_id'],SD::STATE_BUY,$api_type);
				$zs_renewals = $product->get_product_price_list($data['product_id'],SD::STATE_RENEWALS,$api_type);
				if(empty($zs_buy_price)){
					$zs = 0;
				}
				$ww = 1;
				$api_type = 3;
				$ww_buy_price = $product->get_product_price_list($data['product_id'],SD::STATE_BUY,$api_type);
				$ww_renewals = $product->get_product_price_list($data['product_id'],SD::STATE_RENEWALS,$api_type);
				if(empty($ww_buy_price)){
					$ww = 0;
				}
				$xs = 1;
				$api_type = 1;
				$xs_buy_price = $product->get_product_price_list($data['product_id'],SD::STATE_BUY,$api_type);
				$xs_renewals = $product->get_product_price_list($data['product_id'],SD::STATE_RENEWALS,$api_type);
				if(empty($xs_buy_price)){
					$xs = 0;
				}
				if(!$zs && !$xs && !$ww){
					$return["msg"] = "该域名暂时不能注册！";
					$return["status"] = false;
					return $return;
				}
				$product_price_list = array();
				$product_api_type = array();
				if($zs){
					$price_list = array();
					$buy_price = $zs_buy_price[0];
					$price1["api_type"] = $buy_price["api_type"];
					$price1["product_price"] = number_format(ceil($buy_price["product_price"]*$discount),2,".","");
					$price1["year"] = 1;
					if(!$zs_renewals[0]){
						$price_list[] = $price1;
					}else{
						$renewals = $zs_renewals[0];
						$price_list[] = $price1;
						$price3["api_type"] = $buy_price["api_type"];
						$price3["product_price"] = number_format(ceil(($buy_price["product_price"] + $renewals["product_price"] * 2)*$discount),2,".","");
						$price3["year"] = 3;
						$price_list[] = $price3;
						$price5["api_type"] = $buy_price["api_type"];
						$price5["product_price"] = number_format(ceil(($buy_price["product_price"] + $renewals["product_price"] * 4)*$discount),2,".","");
						$price5["year"] = 5;
						$price_list[] = $price5;
						$price10["api_type"] = $buy_price["api_type"];
						$price10["product_price"] = number_format(ceil(($buy_price["product_price"] + $renewals["product_price"] * 9)*$discount),2,".","");
						$price10["year"] = 10;
						$price_list[] = $price10;
					}
					$product_price_list[5] = $price_list;
					$product_api_type[5] = "中国数据";
				}
				if($ww){
					$price_list = array();
					$buy_price = $ww_buy_price[0];
					$price1["api_type"] = $buy_price["api_type"];
					$price1["product_price"] = number_format(ceil($buy_price["product_price"]*$discount),2,".","");
					$price1["year"] = 1;
					if(!$ww_renewals[0]){
						$price_list[] = $price1;
					}else{
						$renewals = $ww_renewals[0];
						$price_list[] = $price1;
						$price3["api_type"] = $buy_price["api_type"];
						$price3["product_price"] = number_format(ceil(($buy_price["product_price"] + $renewals["product_price"] * 2)*$discount),2,".","");
						$price3["year"] = 3;
						$price_list[] = $price3;
						$price5["api_type"] = $buy_price["api_type"];
						$price5["product_price"] = number_format(ceil(($buy_price["product_price"] + $renewals["product_price"] * 4)*$discount),2,".","");
						$price5["year"] = 5;
						$price_list[] = $price5;
						$price10["api_type"] = $buy_price["api_type"];
						$price10["product_price"] = number_format(ceil(($buy_price["product_price"] + $renewals["product_price"] * 9)*$discount),2,".","");
						$price10["year"] = 10;
						$price_list[] = $price10;
					}
					$product_price_list[3] = $price_list;
					$product_api_type[3] = "万网（新）";
				}
				if($xs){
					$price_list = array();
					$buy_price = $xs_buy_price[0];
					$price1["api_type"] = $buy_price["api_type"];
					$price1["product_price"] = number_format(ceil($buy_price["product_price"]*$discount),2,".","");
					$price1["year"] = 1;
					if(!$xs_renewals[0]){
						$price_list[] = $price1;
					}else{
						$renewals = $xs_renewals[0];
						$price_list[] = $price1;
						$price3["api_type"] = $buy_price["api_type"];
						$price3["product_price"] = number_format(ceil(($buy_price["product_price"] + $renewals["product_price"] * 2)*$discount),2,".","");
						$price3["year"] = 3;
						$price_list[] = $price3;
						$price5["api_type"] = $buy_price["api_type"];
						$price5["product_price"] = number_format(ceil(($buy_price["product_price"] + $renewals["product_price"] * 4)*$discount),2,".","");
						$price5["year"] = 5;
						$price_list[] = $price5;
						$price10["api_type"] = $buy_price["api_type"];
						$price10["product_price"] = number_format(ceil(($buy_price["product_price"] + $renewals["product_price"] * 9)*$discount),2,".","");
						$price10["year"] = 10;
						$price_list[] = $price10;
					}
					$product_price_list[1] = $price_list;
					$product_api_type[1] = "西部数码";
				}
				$params['price_list'] = $product_price_list;
				$params['product_api_type'] = $product_api_type;
			}else{
				$price_list = array();
				$api_type = $data["api_type"];
				$buy_price = $product->get_product_price_list($data['product_id'],SD::STATE_BUY,$api_type);
				$renewals = $product->get_product_price_list($data['product_id'],SD::STATE_RENEWALS,$api_type);
				if(!$buy_price[0]){
					$return["msg"] = "该域名暂时不能注册！";
					$return["status"] = false;
					return $return;
				}
				$buy_price = $buy_price[0];
				$price1["api_type"] = $buy_price["api_type"];
				$price1["product_price"] = number_format(ceil($buy_price["product_price"]*$discount),2,".","");
				$price1["year"] = 1;
				if(!$renewals[0]){
					$price_list[] = $price1;
				}else{
					$renewals = $renewals[0];
					$price_list[] = $price1;
					$price3["api_type"] = $buy_price["api_type"];
					$price3["product_price"] = number_format(ceil(($buy_price["product_price"] + $renewals["product_price"] * 2)*$discount),2,".","");
					$price3["year"] = 3;
					$price_list[] = $price3;
					$price5["api_type"] = $buy_price["api_type"];
					$price5["product_price"] = number_format(ceil(($buy_price["product_price"] + $renewals["product_price"] * 4)*$discount),2,".","");
					$price5["year"] = 5;
					$price_list[] = $price5;
					$price10["api_type"] = $buy_price["api_type"];
					$price10["product_price"] = number_format(ceil(($buy_price["product_price"] + $renewals["product_price"] * 9)*$discount),2,".","");
					$price10["year"] = 10;
					$price_list[] = $price10;
				}
				$params['product_price_list'] = $price_list;
			}
		}
		$product_id = $data["product_id"];
		$domain_type = $data["api_ptype"];
		$domain = $data["domain"];
		//获取最近一条联系人信息
		$contact = $this->get_recently_contact($member_id);
		//获取域名产品信息
		$info = $product->get_product($product_id);
		if(empty($info)){
			$return["msg"] = business_code(-2);
			$return["status"] = false;
			return $return;
		}
		if(GD::PTYPE_DOMAIN !== $info["api_name"]){
			$return["msg"] = business_code(-2);
			$return["status"] = false;
			return $return;
		}
		//查询域名是否注册
		/*$query = $this->check_domain($domain_type,$domain,$info["id"]);
		if($query !== -1){
			return $query;
		}*/
		//封装信息
		$params["contact"] = $contact;
		$params["info"] = $info;
		$params["reg_domain"] = $domain;
		return $params;
	}

	/**
	 * 显示域名注册
	 * @date: 2016年11月27日 上午11:11:48
	 * @author: Lyubo
	 * @param $domain_type
	 * @param $domain
	 * @param $id
	 * @return bool
	 */
	public function check_domain($domain_type,$domain,$id){
		$product = new ProductModel();
		$product_info = $product->product_by_id($id,$domain_type);
		if(!$product_info){
			return -2;
		}
		if($product_info["api_name"] !== GD::PTYPE_DOMAIN){
			return -2;
		}
		$suffix[0] = $product_info["product_name"];
		$api_config = WebSiteConfig(2);//获取网站配置
		$api_access = $api_config["api_access"] + 0;
		$api_access = $api_access ? $api_access : 1;
		$agent = new AgentAide(1,$api_access);
		$transaction = $agent->servant;
		try{
			$result = $transaction->new_domain_quary($domain,$suffix);
			api_log(-1,$domain.$suffix[0]."域名查询",$result,"查询成功");
		}catch(\Exception $e){
			api_log(-1,$domain.$suffix[0]."域名查询",$e->getMessage(),"查询失败");
			return -9;
		}
		$xstr = json_decode($result,true);
		if($xstr["code"] != 0){
			return $xstr["code"];
		}
		//可以注册列表
		$yesList = $xstr["info"]["yesList"];
		//查询失败列表
		$failList = $xstr["info"]["failList"];
		//不可注册列表
		$noList = $xstr["info"]["noList"];
		//修改状态
		$product_name = $product_info["product_name"];
		if($product_name === ".top"){
			if(!empty($xstr["info"]["queryfreedomain"][$domain.$product_name])){
				$return["queryfreedomain"] = "yes";
				$return["price"] = $xstr["info"]["queryfreedomain"][$domain.$product_name];
				return $return;
			}
		}
		//可以注册
		if(in_array($product_name,$yesList)){
			return -1;
		}
		//查询失败
		if(in_array($product_name,$failList)){
			return -43;
		}
		//不可以注册
		if(in_array($product_name,$noList)){
			return -42;
		}
		return -43;
	}

	/**
	 * 获取最近1条联系人信息
	 * @date: 2016年11月27日 上午11:16:07
	 * @author: Lyubo
	 * @param $member_id
	 * @return mixed
	 */
	public function get_recently_contact($member_id){
		$domain_contact = M("domain_contact");
		$where['user_id'] = ["eq",$member_id];
		return $domain_contact->field("id,domain_business_id,user_id,create_time,dwmc,dwmcYW,zcrX,zcrM,zcrGJ,zcrSF,zcrCS,zcrDZ,zcrDZ2,zcrYZBM,zcrYX,zcrDH,zcrCZ,zjhm")
							  ->where($where)->order("create_time DESC")->find();
	}

	/**
	 * 验证联系人信息
	 * @date: 2016年11月27日 上午11:54:11
	 * @author: Lyubo
	 * @param $contact
	 * @return int
	 */
	public function domain_var_contact($contact,$data){
		//单位名称正则表达式
		$regDWMC = "/^(([\x{4e00}-\x{9fa5}]+\（[\x{4e00}-\x{9fa5}]+\）[\x{4e00}-\x{9fa5}]*)|([\x{4e00}-\x{9fa5}])){2,25}$/u";
		//中文正则表达式
		$regZW = "/^[\x{4e00}-\x{9fa5}]{1,2}$/u";
		// 数字正则表达式
		$regSZ = "/[0-9]{6}/";
		// 手机正则表达式
		$regDH = "/1[0-9]{10}/";
		// 通讯地址英文正则表达式
		$regDZ2 = "/[a-zA-Z0-9]{6,64}/";
		// 邮箱正则表达式
		$regYX = "/[A-Za-z0-9]+@([_A-Za-z0-9]+\\.)+[A-Za-z0-9]{2,3}/";
		// 单位名称只能为中文字符，且长度<2
		if(strlen($contact ["dwmc"]) < 2 || !preg_match($regDWMC,str_replace(" ","",$contact ["dwmc"]))){
			return -18;
		}
		// 英文单位名称只能为字母数字,且长度为3-200
		if(!preg_match("/[a-zA-Z]{3,200}/",$contact ["dwmcYW"])){
			return -19;
		}
		// 注册人姓只能为中文
		if(!preg_match($regZW,$contact ["zcrX"])){
			return -20;
		}
		// 注册人名只能为中文
		if(!preg_match($regZW,$contact ["zcrM"])){
			return -21;
		}
		// 注册人国家只能为中国
		if($contact ["zcrGJ"] != "中国"){
			return -22;
		}
		//证件号码为1-30位
		if(strlen($contact["zjhm"]) == 0 || strlen($contact["zjhm"]) > 30){
			return -45;
		}
		// 注册人地址英文只能为数字字母，且长度6-64
		if(!preg_match($regDZ2,$contact ["zcrDZ2"])){
			return -23;
		}
		// 注册人邮政编码只能为数字，长度为6
		if(!preg_match($regSZ,$contact["zcrYZBM"]) || strlen($contact["zcrYZBM"]) != 6 || $contact["zcrYZBM"] == 0){
			return -24;
		}
		// 注册人电话(手机号码)
		if(!preg_match($regDH,$contact["zcrDH"])){
			return -25;
		}
		// 注册人邮箱错误
		if(!preg_match($regYX,$contact["zcrYX"])){
			return -27;
		}
		$user_id = session("user_id");
		$product_id = $data["product_id"];
		$domain_type = $data["api_ptype"];
		$domain = $data["domain"];
		//获取域名产品信息
		$product = new ProductModel();
		$info = $product->get_product($product_id);
		if(empty($info)){
			return -2;
		}
		$dm = new DomainModel();
		$request = $dm->check_domain($domain_type,$domain,$product_id);
		if($request !== -1){
			return $request;
		}
		return -1;
	}

	/**
	 * 域名注册调用接口
	 * @date: 2016年11月27日 下午1:48:21
	 * @author: Lyubo
	 * @return int
	 */
	public function domain_register(){
		$data = request(true);
		//封装联系人参数
		$contact["dwmc"] = $data["dwmc"];
		$contact["dwmcYW"] = trim($data["dwmcYW"]);
		$contact["zjhm"] = $data["zjhm"];
		$contact["zcrX"] = $data["zcrX"];
		$contact["zcrM"] = $data["zcrM"];
		$contact["zcrGJ"] = $data["zcrGJ"];
		$contact["zcrSF"] = $data["zcrSF"];
		$contact["zcrCS"] = $data["zcrCS"];
		$contact["zcrDZ"] = trimall($data["zcrDZ"]);
		$contact["zcrDZ2"] = trimall($data["zcrDZ2"]);
		$contact["zcrYZBM"] = $data["zcrYZBM"];
		$contact["zcrYX"] = $data["zcrYX"];
		$contact["zcrDH"] = $data["zcrDH"];
		$contact['zcrCZ'] = $data['zcrDH'];
		//验证联系人信息
		$var_code = $this->domain_var_contact($contact,$data);
		if(!is_array($var_code)){
			if($var_code != -1){
				$return["msg"] = business_code($var_code);
				$return["status"] = false;
				return $return;
			}
		}
		if($var_code["queryfreedomain"] == "yes"){
			$price = $var_code["price"];
		}else{
			$price = $data["price"];
		}
		$api_type = $data["api_type"];
		$product_id = $data["product_id"];
		$domain = $data['domain'];
		$member_id = session("user_id");
		$buy_time = $price;
		$buy_num = 1;
		$api_config = WebSiteConfig(2);//获取网站配置
		$api_access = $api_config["api_access"] + 0;
		$api_access = $api_access ? $api_access : 1;
		$product = new ProductModel();
		$order = new OrderModel();
		//添加联系人表
		$contact["user_id"] = $member_id;
		$contact["create_time"] = date('Y-m-d H:i:s');
		$domain_contact = M("domain_contact");
		$add_contact = $domain_contact->add($contact);
		if(!$add_contact){
			$return["msg"] = business_code(-17);//添加联系人信息失败
			$return["status"] = false;
			return $return;
		}
		$contact_id = $domain_contact->getLastInsID();
		$queryfreedomain = false;
		if($buy_time > 10){
			$queryfreedomain = true;
		}
		$params["user_id"] = $member_id;
		$params["product_id"] = $product_id;
		$params["free_trial"] = 0;
		$params["order_time"] = $queryfreedomain ? 12 : $buy_time*12;
		$params["order_quantity"] = $buy_num;
		$params["system_type"] = $api_type;
		$params['access'] = $api_access;
		$params["root_domain"] = $queryfreedomain ? $buy_time : 0;
		// 获取产品信息
		$product_info = $product->get_product($product_id);
		if(!$product_info || $product_info ["product_state"] == 0){
			$return["msg"] = business_code(-2);//产品信息获取失败
			$return["status"] = false;
			return $return;
		}
		//拼接域名
		$domain = $domain.$product_info ["product_name"];
		//录入订单
		$order_id = $order->order_do_entry($params,$member_id,SD::NEW_ORDER,$product_info,null,$domain,$api_type);
		if($order_id <= 0){
			$return["msg"] = business_code($order_id);
			$return["status"] = false;
			return $return;
		}
		$agent = new AgentAide(1,$api_access);
		$transaction = $agent->servant;
		$api_contact = $this->api_contact($contact);//处理联系人信息为API参数
		if($api_type == 1 || $api_type == 100012){
			$api_type = 100012;
		}elseif($api_type == 3 || $api_type == 100014){
			$api_type = 100014;
		}else{
			$api_type = 5;
		}
		$yid = $queryfreedomain ? 12 : $buy_time*12;
		$ptype = GD::PTYPE_DOMAIN;
		$pname = GD::PNAME_DOMAIN_REGISTRATION;
		$tid = GD::TID_DOMAIN;
		$log_info = "ptype:".$ptype."-pname:".$pname."-tid:".$tid."-yid:".$yid."-input_name:".$api_type."-domainname:".$domain;
		/**调用接口，域名注册*/
		try{
			$result = $transaction->domainregistration($domain,$api_contact,$yid,$api_type);
			//修改订单失败，默认失败，添加业务表信息成功时再修改成功
			$order_data['state'] = SD::FAILURE_ORDER;
			$order->order_edit($order_id,$order_data);
			$log_message = '域名注册，域名：['.$domain.']';
			api_log($member_id,$log_info,$result,$log_message);
		}catch(\Exception $e){
			$log_message = '域名注册，域名：['.$domain.']接口调用失败失败';
			api_log($member_id,$log_info,$e->getMessage(),$log_message);
			$return["msg"] = business_code(-9);
			$return["status"] = false;
			return $return;
		}
		$xstr = json_decode($result,true);
		if($xstr['code'] != 0){
			if($xstr['code'] == 1120){
				$return["msg"] = 1120;
			}else{
				$return["msg"] = business_code($xstr['code']);
			}
			$return["status"] = false;
			return $return;
		}
		//修改订单处理中
		$order->order_edit($order_id,array("state"=>SD::HANDLE_ORDER,"api_id"=>$xstr["info"]["orderId"],"business_id"=>$xstr["info"]["orderId"]));
		if($api_type == 3 || $api_type == 100014){
			$return["status"] = true;
			return $return;
			/*$pname = "getbusinfobydid";
			$log_info = "ptype:".$ptype."-pname:".$pname."-tid:".$tid."-did:".$xstr["info"]["orderId"];
			try{
				$result = $transaction->getbusinfobydid($xstr["info"]["orderId"]);
				$log_message = '获取域名业务信息成功';
				api_log($member_id,$log_info,$result,$log_message);
			}catch(\Exception $e){
				$log_message = '域名注册成功,添加域名业务信息失败';
				api_log($member_id,$log_info,$e->getMessage(),$log_message);
				$return["msg"] = business_code(-122);
				$return["status"] = false;
				return $return;
			}
			$xstr = json_decode($result,true);*/
		}
		if($xstr['code'] != 0){
			$return["msg"] = business_code($xstr['code']);
			$return["status"] = false;
			return $return;
		}
		$parms["mm"] = $xstr["info"]["domainPwd"];
		/**调用接口，获取业务信息*/
		try{
			$result = $transaction->getdomaininfo($xstr["info"]["busiId"]);
			$log_message = '获取域名业务信息成功';
			api_log($member_id,"ptype:".GD::PTYPE_DOMAIN."-pname:".GD::PNAME_DOMAIN_LIST."-tid:".GD::TID_DOMAIN,$result,$log_message);
			$json = json_decode($result,true);
			if($json['code'] != 0){
				$return["msg"] = business_code($json['code']);
				$return["status"] = false;
				return $return;
			}
		}catch(\Exception $e){
			$log_message = '域名注册成功,添加域名业务信息失败';
			api_log($member_id,"ptype:".GD::PTYPE_DOMAIN."-pname:".GD::PNAME_DOMAIN_LIST."-tid:".GD::TID_DOMAIN,$e->getMessage(),$log_message);
			$return["msg"] = business_code(-122);
			$return["status"] = false;
			return $return;
		}
		//域名业务列表
		$domain_list = $json['info'];
		//域名业务编号
		$domain_business_id = null;
		$domain_order_id = $domain_list["orderId"];
		$domain_psd = $domain_list["mm"];
		$parms["user_id"] = $member_id;
		$parms['product_id'] = $product_id;
		$parms['create_time'] = $domain_list['createDate'];
		$parms['overdue_time'] = $domain_list['overDate'];
		$parms['api_bid'] = $domain_list['api_bid'];
		$parms['product_name'] = $domain_list['product_name'];
		$parms['domain_name'] = $domain_list['domain_name'];
		$parms['access'] = $api_access;
		$parms['yijia'] = $queryfreedomain ? 1 : 0;
		$date = date('Y-m-d H:i:s');
		if($domain_list['overDate'] < $date){
			$parms['state'] = '0';
		}else{
			$parms['state'] = '1';
		}
		$parms['mm'] = $domain_psd;
		//1:西部数码3：万网4：新网5：中国数据6：新网互联7:ResellerClub
		if($domain_list['api_type'] == 100004){
			$parms['provider'] = '新网互联';
			$parms['api_type'] = 6;
		}else if($domain_list['api_type'] == 100006){
			$parms['provider'] = 'ResellerClub';
			$parms['api_type'] = 7;
		}else if($domain_list['api_type'] == 100012){
			$parms['provider'] = '西部数码';
			$parms['api_type'] = 1;
		}else if($domain_list['api_type'] == 100014){
			$parms['provider'] = '万网（新）';
			$parms['api_type'] = 1;
		}else{
			$parms['api_type'] = $domain_list['api_type'];
			if($domain_list['api_type'] == 3){
				$parms['provider'] = '万网（新）';
			}else if($domain_list['api_type'] == 4){
				$parms['provider'] = '新网';
			}else if($domain_list['api_type'] == 5){
				$parms['provider'] = '中国数据';
			}
		}
		$parms['fdnsym'] = $domain_list['fdnsym'];
		$parms['zdnsym'] = $domain_list['zdnsym'];
		$add_domain = $this->add($parms);
		if(!$add_domain){
			$return["msg"] = business_code(-18);
			$return["status"] = false;
			return $return;
		}
		$domain_business_id = $this->getLastInsID();
		if($domain_business_id != null){
			//修改订单成功
			$order_data['state'] = SD::SUCCESS_ORDER;
			$order_data['api_id'] = $domain_order_id;
			$order->order_edit($order_id,$order_data);
			//修改域名业务ID信息
			$upd_contact['domain_business_id'] = $domain_business_id;
			$contact_where['id'] = ["eq",$contact_id];
			$this->update_domain_contact($contact_where,$upd_contact);
			//删除没有域名业务ID的联系人信息
			$del_contact['user_id'] = ['eq',$member_id];
			$del_contact['domain_business_id'] = ['exp','is null'];
			$this->delete_domain_contact($del_contact);
			$return["status"] = true;
			return $return;
		}
		$return["msg"] = business_code(-15);
		$return["status"] = false;
		return $return;
	}

	/**
	 * 处理联系人为API参数
	 * @date: 2016年11月27日 下午2:31:39
	 * @author: Lyubo
	 * @param $contact
	 * @return string
	 */
	private function api_contact($contact){
		$domainparams = "";
		$domainparams .= "dwmc:".$contact ["dwmc"];
		$domainparams .= "-dwmcYW:".$contact ["dwmcYW"];
		$domainparams .= "-zcrX:".$contact ["zcrX"];
		$domainparams .= "-zcrM:".$contact ["zcrM"];
		$domainparams .= "-zcrGJ:".$contact ["zcrGJ"];
		$domainparams .= "-zcrSF:".$contact ["zcrSF"];
		$domainparams .= "-zcrCS:".$contact ["zcrCS"];
		$domainparams .= "-zcrDZ:".$contact ["zcrDZ"];
		$domainparams .= "-zcrDZ2:".$contact ["zcrDZ2"];
		$domainparams .= "-zcrYZBM:".$contact ["zcrYZBM"];
		$domainparams .= "-zcrYX:".$contact ["zcrYX"];
		$domainparams .= "-zjhm:".$contact ["zjhm"];
		$domainparams .= "-zcrDH:".strtr($contact ["zcrDH"],"-","+"); //-号替换为+号
		$domainparams .= "-isPersonal:".$contact ["isPersonal"];
		$domainparams .= "-zcrName:".$contact ["zcrName"];
		$domainparams .= "-zcrNameEn:".$contact ["zcrNameEn"];
		$domainparams .= "-zcrYX:".$contact ["zcrYX"];
		$domainparams .= "-isPersonal:".$contact ["isPersonal"];
		$domainparams .= "-zcrName:".$contact ["zcrName"];
		$domainparams .= "-zcrNameEn:".$contact ["zcrNameEn"];
		$domainparams .= "-zcrYX:".$contact ["zcrYX"];
		return $domainparams;
	}

	/**
	 * 域名续费展示
	 * @date: 2016年12月3日 上午11:41:25
	 * @author: Lyubo
	 * @param: $domain_id,$member_id
	 * @return: $domain_info
	 */
	public function domain_renewals_info($domain_id,$member_id){
		$where["db.id"] = ["eq",$domain_id];
		$where["db.user_id"] = ["eq",$member_id];
		return $this->alias(' db ')
					->field("db.id,domain_name,db.user_id,db.create_time,db.overdue_time,api_bid,provider,state,product_id,db.product_name, api_type,db.access,p.product_type_id")
					->join("left join ".C('DB_PREFIX')."product p on (p.id=db.product_id)")->where($where)->find();
	}

	/**
	 * 域名续费
	 * @date: 2016年12月3日 下午3:19:20
	 * @author: Lyubo
	 * @param: $domain_id,$member_id,$renewals_time
	 * @return boolean
	 */
	public function domain_renewals($domain_id,$member_id,$renewals_time){
		$product = new ProductModel();
		$order = new OrderModel();
		$where['id'] = ["eq",$domain_id];
		$where["user_id"] = ["eq",$member_id];
		$domain_info = $this->where($where)->find();
		//获取不到业务信息或业务状态错误
		if(!$domain_info || $domain_info ["state"] != 1){
			return -10;
		}
		//计算过期时间
		$over_day = overdue_day($domain_info["overdue_time"]);
		if($over_day < -31){
			return -36;
		}
		//获取不到接口业务编号
		if(!$domain_info ["api_bid"]){
			return -11;
		}
		// 获取产品信息
		$product_info = $product->get_product($domain_info ["product_id"]);
		if(!$product_info || $product_info ["product_state"] == 0){
			return -2;
		}
		$api_access = $domain_info["access"] + 0;
		$api_access = $api_access ? $api_access : 1;
		$params ["product_id"] = $domain_info["product_id"];
		$params ["order_time"] = $renewals_time;
		$params ["order_quantity"] = 1;
		$params["business_id"] = $domain_id;
		$dataarray = array(
			"user_id" => $member_id,
			"order_type" => SD::RENEWALS_ORDER, // 续费
			"state" => SD::FAILURE_ORDER,
			"ip_address" => $domain_info['domain_info'],
			"product_type" => $product_info['product_type_id'],
			"product_id" => $product_info['id'],
			"product_name" => $domain_info['domain_name'],
			"free_trial" => 0, // 不是试用
			"order_time" => $renewals_time, // 续费12个月
			"order_quantity" => 1,
			"business_id" => $domain_id,
			"create_time" => current_date(),
			"login_name" => $domain_info['login_name'],
			"complete_time" => current_date(),
			'order_log' => '会员'.$member_id."续费".$domain_info['domain_name'].'域名',
			"access" => $api_access
		);
		//录入订单
		$product_type_info['business_id'] = $domain_info['id'];
		$api_type = $domain_info["api_type"];
		$order_id = $order->order_do_entry($dataarray,$domain_info["user_id"],SD::RENEWALS_ORDER,$product_info,null,null,$api_type,$domain_info['id']);
		if($order_id <= 0){
			return $order_id;
		}
		$json = null;
		$agent = new AgentAide(1,$api_access);
		$transaction = $agent->servant;
		$ptype = GD::PTYPE_DOMAIN;
		$pname = GD::PNAME_DOMAIN_RENEWALS;
		$tid = GD::TID_DOMAIN;
		$bid = $domain_info["api_bid"];
		$yid = $renewals_time;
		try{
			/*调用接口，域名续费*/
			$result = $transaction->domainrenewals($bid,$yid);
			$json = json_decode($result,true);
			api_log($member_id,"ptype:".$ptype."--pname:".$pname."--tid:".$tid."--bid:".$bid."--yid:".$yid,$result,$dataarray["order_log"],"域名续费");
		}catch(\Exception $e){
			api_log($member_id,"ptype:".$ptype."--pname:".$pname."--tid:".$tid."--bid:".$bid."--yid:".$yid,$e->getMessage(),"域名续费失败—接口调用失败");
			//修改订单状态
			$order_data["state"] = SD::FAILURE_ORDER;
			$order_data["order_log"] = $dataarray["order_log"]."-接口调用失败";
			$order->order_edit($order_id,$order_data);
			return -9;
		}
		if($json == null){
			return -9;
		}
		//返回API code
		if($json['code'] != 0){
			return $json['code'];
		}
		/*域名业务续费时间*/
		$ren = $this->execute("UPDATE `agent_domain_business` SET `overdue_time`= DATE_ADD(overdue_time, INTERVAL {$renewals_time} MONTH) WHERE `id` = {$domain_id}",false);
		if($ren === false){
			return -12;
		}
		//修改订单成功
		$order_data["state"] = SD::SUCCESS;
		$order->order_edit($order_id,$order_data);
		return -1;
	}

	/**
	 * 修改域名联系人表business_id
	 * @date: 2016年11月27日 下午3:21:29
	 * @author: Lyubo
	 * @param: $contact_id
	 * @param: $upd_contact
	 * @return boolean
	 */
	public function update_domain_contact($contact_where,$upd_contact){
		$domain_contact = M("domain_contact");
		return $domain_contact->where($contact_where)->save($upd_contact);
	}

	/**
	 * 删除没有域名业务ID的联系人信息
	 * @date: 2016年11月27日 下午3:35:30
	 * @author: Lyubo
	 * @param: $member_id，$del_contact
	 * @return boolean
	 */
	public function delete_domain_contact($del_contact){
		$domain_contact = M("domain_contact");
		return $domain_contact->where($del_contact)->delete();
	}

	/**
	 * 西数域名解析
	 * @date: 2018年8月21日14:09:09
	 * @author: Guopeng
	 * @param $data
	 * @param string $method
	 * @return int|mixed
	 */
	public function domain_analysis($data,$method = "get"){
		$bid = $data["bid"] + 0;
		$uid = session('user_id') + 0;
		if($bid == 0){
			$this->error = business_code(-10);
			return -10;
		}
		$where["api_bid"] = $bid;
		$where["user_id"] = $uid;
		$domain_info = $this->where($where)->find();
		if(!$domain_info){
			$this->error = business_code(-10);
			return -10;
		}
		$analysis = M("domain_analysis");
		if($method == "get"){
			$info = $analysis->where(["domain_id"=>$domain_info["id"]])->select();
			return $info;
		}else{
			$api_access = $domain_info["access"] + 0;
			$api_access = $api_access ? $api_access : 1;
			$agent = new AgentAide(1,$api_access);
			$transaction = $agent->servant;
			$ptype = GD::PTYPE_DOMAIN;
			$tid = GD::TID_DOMAIN;
			$submit = $data["submit"];
			if($submit == "sync"){
				$pname = GD::PNAME_DOMAIN_GETDNS;
				try{
					/*调用接口，域名续费*/
					$result = $transaction->domain_get_dns_record($bid);
					api_log($uid,"ptype:".$ptype."-pname:".$pname."-tid:".$tid."-bid:".$bid,$result,"获取域名解析记录");
				}catch(\Exception $e){
					api_log($uid,"ptype:".$ptype."-pname:".$pname."-tid:".$tid."-bid:".$bid,$e->getMessage(),"获取域名解析记录失败—接口调用失败");
					$this->error = business_code(-9);
					return -9;
				}
				$json = json_decode($result,true);
				if($json["code"] != 0){
					$this->error = business_code($json["code"]);
					return $json["code"];
				}
				$info = $json["info"];
				$dns_ids = array();
				foreach($info as $key=>$list){
					if($key == "mxList"){
						$type = "MX";
					}elseif($key == "txtList"){
						$type = "TXT";
					}elseif($key == "cnameList"){
						$type = "CNAME";
					}elseif($key == "aList"){
						$type = "A";
					}
					foreach($list as $v){
						$dns_ids[] = $v["id"];
						$arr = array(
							"domain_id" => $domain_info["id"],
							"dns_id" => $v["id"],
							"name" => $v["name"],
							"content" => $v["value"],
							"prior" => $v["prio"],
							"ttl" => $v["ttl"],
							"type" => $type
						);
						$res = $analysis->where(["domain_id" => $domain_info["id"],"dns_id" => $v["id"]])->find();
						if($res){
							$analysis->where(["domain_id" => $domain_info["id"],"dns_id" => $v["id"]])->save($arr);
						}else{
							$analysis->add($arr);
						}
					}
				}
				$sync_where["domain_id"] = $domain_info["id"];
				if($dns_ids){
					$sync_where["dns_id"] = array("not in",$dns_ids);
				}
				$analysis->where($sync_where)->delete();
				return -1;
			}elseif($submit == "add"){
				$name = $data["name"];
				$type = $data["type"];
				$content = $data["content"];
				$prio = $data["type"] == "MX" ? $data["prio"] ? $data["prio"] : 5 : "";
				$ttl = $data["ttl"]+0;
				$ttl = $ttl ? $ttl : 600;
				$arr = array(
					"tldomain" => $name,
					"analytic_value" => $content,
					"analytic_type" => $type
				);
				$pname = GD::PNAME_DOMAIN_ADDDNS;
				$log = "ptype:".$ptype."-pname:".$pname."-tid:".$tid."-bid:".$bid."-tldomain:".$name."-analytic_type:".$type."-analytic_value:".$content;
				try{
					/*调用接口，域名续费*/
					$result = $transaction->domain_add_dns_record($bid,$arr);
					api_log($uid,$log,$result,"添加域名解析记录");
				}catch(\Exception $e){
					api_log($uid,$log,$e->getMessage(),"添加域名解析记录失败—接口调用失败");
					$this->error = business_code(-9);
					$this->error = "添加域名解析记录失败";
					return -9;
				}
				$json = json_decode($result,true);
				if($json["code"] != 0){
					$this->error = business_code($json["code"]);
					return $json["code"];
				}
				//添加成功 同步解析记录
				try{
					/*调用接口，域名续费*/
					$result = $transaction->domain_get_dns_record($bid);
				}catch(\Exception $e){
					api_log($uid,"ptype:".$ptype."-pname:".$pname."-tid:".$tid."-bid:".$bid,$e->getMessage(),"获取域名解析记录失败—接口调用失败");
					$this->error = "添加域名解析记录成功，添加数据库记录失败！请手动同步解析记录！";
					return -9;
				}
				$json = json_decode($result,true);
				if($json["code"] != 0){
					api_log($uid,"ptype:".$ptype."-pname:".$pname."-tid:".$tid."-bid:".$bid,$result,"获取域名解析记录失败—接口调用失败");
					$this->error = "添加域名解析记录成功，添加数据库记录失败！请手动同步解析记录！";
					return $json["code"];
				}
				$info = $json["info"];
				$dns_ids = array();
				foreach($info as $key=>$list){
					if($key == "mxList"){
						$type = "MX";
					}elseif($key == "txtList"){
						$type = "TXT";
					}elseif($key == "cnameList"){
						$type = "CNAME";
					}elseif($key == "aList"){
						$type = "A";
					}
					foreach($list as $v){
						$dns_ids[] = $v["id"];
						$arr = array(
							"domain_id" => $domain_info["id"],
							"dns_id" => $v["id"],
							"name" => $v["name"],
							"content" => $v["value"],
							"prior" => $v["prio"],
							"ttl" => $v["ttl"],
							"type" => $type
						);
						$res = $analysis->where(["domain_id" => $domain_info["id"],"dns_id" => $v["id"]])->find();
						if($res){
							$analysis->where(["domain_id" => $domain_info["id"],"dns_id" => $v["id"]])->save($arr);
						}else{
							$analysis->add($arr);
						}
					}
				}
				$analysis->where(["domain_id" => $domain_info["id"],"dns_id" => array("not in",$dns_ids)])->delete();
				return -1;
			}elseif($submit == "update"){
				$newRecord = $data["content"];
				$id = $data["id"]+0;
				$ainfo = $analysis->where(["domain_id"=>$domain_info["id"],"id" => $id])->find();
				if(!$ainfo){
					$this->error = business_code(-10);
					return -10;
				}
				$dns_id = $ainfo["dns_id"];
				$pname = GD::PNAME_DOMAIN_UPDATEDNS;
				$log = "ptype:".$ptype."-pname:".$pname."-tid:".$tid."-bid:".$bid."-newRecord:".$newRecord;
				try{
					/*调用接口，域名续费*/
					$result = $transaction->domain_update_dns_record($bid,$dns_id,$newRecord);
					api_log($uid,$log,$result,"修改域名解析记录");
				}catch(\Exception $e){
					api_log($uid,$log,$e->getMessage(),"修改域名解析记录失败—接口调用失败");
					$this->error = business_code(-9);
					return -9;
				}
				$json = json_decode($result,true);
				if($json["code"] != 0){
					$this->error = business_code($json["code"]);
					$this->error = "修改域名解析记录失败";
					return $json["code"];
				}
				$res = $analysis->where(["domain_id"=>$domain_info["id"],"id" => $id])->save(["content"=>$newRecord]);
				if($res === false){
					$this->error = "修改域名解析记录成功，数据库修改失败！请手动同步解析记录！";
					return -9;
				}
				return -1;
			}elseif($submit == "delete"){
				$id = $data["id"]+0;
				$ainfo = $analysis->where(["domain_id"=>$domain_info["id"],"id" => $id])->find();
				if(!$ainfo){
					$this->error = business_code(-10);
					return -10;
				}
				$dns_id = $ainfo["dns_id"];
				$pname = GD::PNAME_DOMAIN_DELDNS;
				$log = "ptype:".$ptype."-pname:".$pname."-tid:".$tid."-bid:".$bid."-dns_id:".$dns_id;
				try{
					/*调用接口，域名续费*/
					$result = $transaction->domain_del_dns_record($bid,$dns_id);
					api_log($uid,$log,$result,"删除域名解析记录");
				}catch(\Exception $e){
					api_log($uid,$log,$e->getMessage(),"删除域名解析记录失败—接口调用失败");
					$this->error = business_code(-9);
					return -9;
				}
				$json = json_decode($result,true);
				if($json["code"] != 0){
					$this->error = business_code($json["code"]);
					$this->error = "删除域名解析记录失败";
					return $json["code"];
				}
				$res = $analysis->where(["domain_id"=>$domain_info["id"],"id" => $id])->delete();
				if($res === false){
					$this->error = "修改域名解析记录成功，数据库修改失败！请手动同步解析记录！";
					return -9;
				}
				return -1;
			}
		}
	}

	/**
	 * 域名实名认证
	 * @date: 2018年12月11日18:11:59
	 * @author: Guopeng
	 * @param bool $m true：获取信息，false：操作
	 * @return int|mixed
	 */
	public function toAuthentication($m){
		$data = request();
		$id = $data["id"];
		$user_id = session("user_id");
		$binfo = $this->where(array("id" => $id,"user_id"=>$user_id))->find();
		if(!$binfo){
			$return["msg"] = "未查询到符合条件的业务";
			$return["status"] = false;
			return $return;
		}
		if($binfo["authentication"] != -1 || $binfo["authentication"] != 2){ //已提交实名
			$return["msg"] = "该业务已经提交实名认证，请勿重复提交";
			$return["status"] = false;
			return $return;
		}
		/*同步域名业务*/
		$Respository = new \Common\Respository\DomainRespository($this);
		$result = $Respository->DomainBusinessSynchronizing($binfo["api_bid"]);
		/*同步后，查看实名状态*/
		$binfo = $this->where(array("id" => $id))->find();//实名状态查询-1未实名 0:已实名 1:审核中 2:审核拒绝 3:实名失败 4:实名异常 5:等待上报 6.资料未提交
		if(!in_array($binfo["authentication"],array(-1,2,3))){ //已实名
			$return["msg"] = "该业务已经提交实名认证，请勿重复提交";
			$return["status"] = false;
			return $return;
		}
		if($m){
			$return["info"] = $binfo;
			$return["status"] = true;
			return $return;
		}
		$provider = array("中国数据"=>5,"西部数码"=>100012,"万网（新）"=>100014);
		$par["ptype"] = $ptype = "domain";
		$par["pname"] = $pname = "realnamedomain";
		$par["tid"] = $tid = "15";
		$par["domainname"] = $domain_name = $binfo["domain_name"];
		$par["input_name"] = $jkbh = $provider[$binfo["provider"]];//注册商类型(5:中国数据,100012:西部数码,100014:万网（新）)
		$par["ownerType"] = $ownerType = $data["ownerType"];//域名类型(1:个人，2:企业)
		$info = "ptype:{$ptype}-pname:{$pname}-tid:{$tid}-domainname:{$domain_name}-input_name:{$jkbh}-ownerType:{$ownerType}";
		$idcart = "/^[a-zA-Z0-9]{8,18}$/";//身份证件验证
		$orgCart = "/^[a-zA-Z0-9]{15,25}$/";//企业证件验证
		$regDWMC = "/^[\x{4e00}-\x{9fa5}]{2,64}$/u";
		if($jkbh == 100012){
			$par["applyName"] = $applyName = $data["applyName"];
			if(!preg_match($regDWMC,str_replace(" ","",$applyName))){
				$return["msg"] = "联系人格式错误（2-64个中文字符）！";
				$return["status"] = false;
				return $return;
			}
			$info .= "-applyName:{$applyName}";
		}
		if(!in_array($ownerType,array(1,2))){
			$return["msg"] = "实名类型错误！";
			$return["status"] = false;
			return $return;
		}
		$idtype = $data["idtype"] + 0;//注册人/联系人证件类型
		$idcode = str_replace(" ","",clearXSS(I("post.")["idcode"]));//注册人/联系人证件号码
		if(!in_array($idtype,array(1,5,6,11,12,27,29))){
			$return["msg"] = "注册人/联系人个人证件类型错误！";
			$return["status"] = false;
			return $return;
		}
		if(!preg_match($idcart,$idcode)){
			$return["msg"] = "注册人/联系人个人证件号码格式错误！";
			$return["status"] = false;
			return $return;
		}
		$par["idtype"] = $idtype;
		$par["idcode"] = $idcode;
		$idCard = $_FILES["idCard"];
		$par["idimgname"] = $idimgname = $idCard["name"];//图片名称(.jpg格式)
		$info .= "-idtype:{$idtype}-idcode:{$idcode}-idimgname:{$idimgname}";
		//验证上传的图片信息
		if(empty($idCard["tmp_name"])){
			$return["msg"] = "请上传注册人/联系人个人证件正面扫描件！";
			$return["status"] = false;
			return $return;
		}
		//验证图片上传大小
		if($idCard["size"] > 1024*1024 || $idCard["size"] < 55*1024){
			$return["msg"] = "上传注册人/联系人个人证件正面扫描件大小应为55KB-1MB！";
			$return["status"] = false;
			return $return;
		}
		if(!in_array(explode("/",$idCard["type"])[1],array("jpg","jpeg"))){
			$return["msg"] = "上传注册人/联系人个人证件正面扫描件类型应为JPG/JPEP格式！";
			$return["status"] = false;
			return $return;
		}
		$img = $idCard["tmp_name"];
		$image_data = fread(fopen($img,"r"),filesize($img));
		$idimgFile = base64_encode($image_data);
		if(empty($idimgFile)){
			$return["msg"] = "未获取到个人证件扫描件，请重新上传！";
			$return["status"] = false;
			return $return;
		}
		$par["idimgFile"] = $idimgFile;//base64(.jpg格式)图片
		if($ownerType == 2){
			$orgprooftype = $data["orgprooftype"] + 0;//组织(企业)证件类型(企业类型必传)
			$orgcode = str_replace(" ","",clearXSS(I("post.")["orgcode"]));//组织(企业)证件号码(企业类型必传)
			if(!in_array($orgprooftype,array(1,2,3,4))){
				$return["msg"] = "组织(企业)证件类型错误！";
				$return["status"] = false;
				return $return;
			}
			if(!preg_match($orgCart,$orgcode)){
				$return["msg"] = "组织(企业)证件号码格式错误！";
				$return["status"] = false;
				return $return;
			}
			$par["orgprooftype"] = $orgprooftype;
			$par["orgcode"] = $orgcode;
			$orgCard = $_FILES["orgCard"];
			$par["orgimgname"] = $orgimgname = $orgCard["name"];//图片名称(.jpg格式)
			$info .= "-orgprooftype:{$orgprooftype}-orgcode:{$orgcode}-orgimgname:{$orgimgname}";
			//验证上传的图片信息
			if(empty($orgCard["tmp_name"])){
				$return["msg"] = "请上传组织(企业)证件扫描件！";
				$return["status"] = false;
				return $return;
			}
			//验证图片上传大小
			if($orgCard["size"] > 1024*1024 || $orgCard["size"] < 55*1024){
				$return["msg"] = "上传组织(企业)证件扫描件大小应为55KB-1MB！";
				$return["status"] = false;
				return $return;
			}
			if(!in_array(explode("/",$orgCard["type"])[1],array("jpg","jpeg"))){
				$return["msg"] = "上传组织(企业)证件扫描件类型应为JPG/JPEP格式！";
				$return["status"] = false;
				return $return;
			}
			$img = $orgCard["tmp_name"];
			$image_data = fread(fopen($img,"r"),filesize($img));
			$orgimgFile = base64_encode($image_data);
			if(empty($orgimgFile)){
				$return["msg"] = "未获取到上传扫描件，请重新上传！";
				$return["status"] = false;
				return $return;
			}
			$par["orgimgFile"] = $orgimgFile;//base64(.jpg格式)图片
		}
		$api_access = $binfo["access"] ? $binfo["access"] : 1;


		$agent = new AgentAide(1,$api_access);
		$transaction = $agent->servant;
		try{
			$result = $transaction->real_name_domain($par);
			api_log($user_id,$info,$result,"{$domain_name}提交域名实名认证信息");
		}catch(\Exception $e){
			$message = $e->getMessage();
			api_log(session("user_id"),$info,$message,"{$domain_name}提交域名实名认证信息-失败");
			$return["msg"] = business_code(-9);
			$return["status"] = false;
			return $return;
		}
		$xstr = json_decode($result,true);
		if($xstr["code"] == 0 && $xstr["code"] !== null){
			$detail = $xstr["info"];
			if(empty($detail)){
				/*实名接口调用成功，生成实名记录,并修改代理平台上的实名状态为审核中*/
				$certify_log["user_id"] = $user_id;
				$certify_log["certify_time"] = date("Y-m-d H:i:s");
				$certify_log["check_status"] = 1;
				$certify_log["idCart"] = $par["idcode"];
				$certify_log["product"] = $binfo["domain_name"];
				$certify_log["pb_id"] = $binfo["id"];
				$certify_log["api_bid"] = $binfo["api_bid"];
				$certify_log["phone"] = "";
				$certify_log["contactname"] = $par["applyName"];
				$certify_log["comptype"] = $par["ownerType"];
				$certify_log["mark"] = "审核中";
				M("certify_log")->add($certify_log);
				$this->where(array("id"=>$id))->save(array("authentication"=>1));
				$return["msg"] = "域名实名认证信息提交成功，请等待审核！";
				$return["status"] = true;
				return $return;
			}else{
				$return["msg"] = $xstr["info"][0]["failinfo"] ? $xstr["info"][0]["failinfo"] : "域名实名认证信息提交失败";
				if($xstr["info"][0]["failinfo"] == "domain-smstatus-error"){
					$this->where(array("id"=>$id))->save(array("authentication"=>1));
					$return["msg"] = "已提交过实名认证，请勿重复提交！";
				}
				if($xstr["info"][0]["failinfo"] == "domain-have-realname"){
					$this->where(array("id"=>$id))->save(array("authentication"=>0));
					$return["msg"] = "已实名成功，请勿重复提交！";
				}
				$return["status"] = false;
				return $return;
			}
		}else{
			$return["msg"] = business_code($xstr["code"]);
			$return["status"] = false;
			return $return;
		}
	}

	/**
	 * 域名实名认证记录查询
	 * @date: 2018年12月11日18:11:59
	 * @author: Guopeng
	 * @return int|mixed
	 */
	public function auth_list(){
		$data = request();
		$user_id = session("user_id");
		$certifylog = new CertifyLogModel();
		if(isset($data["id"])){
			$id = $data["id"]+0;
			$binfo = $this->where(array("id" => $id,"user_id"=>$user_id))->find();
			if(!$binfo){
				$return["msg"] = "未查询到符合条件的业务！";
				$return["status"] = false;
				return $return;
			}
			$where["user_id"] = $user_id;
			$where["pb_id"] = $id;
			$where["api_bid"] = $binfo["api_bid"];
			$where["product"] = $binfo["domain_name"];
		}else{
			$where["user_id"] = $user_id;
		}
		$info = $certifylog->get_log_list($where,10,"*","");
		foreach($info["list"] as $k => &$v){
			$v["idcart"] = substr_replace($v["idcart"],"*******",4,12);
			$v["contactname"] = mb_substr($v["contactname"],0,1,'utf-8')."**";
		}
		/*审核状态如何判定，及审核说明情况 */
		return $info;
	}

	/**
	 * 万网（新）域名注册邮箱验证ajax
	 * @date: 2018年12月26日17:53:30
	 * @author: Guopeng
	 */
	public function check_domain_mail(){
		$data = request();
		$mail = $data["mail"];
		$uid = session("user_id");
		// 邮箱正则表达式
		$regYX = "/[A-Za-z0-9]+@([_A-Za-z0-9]+\\.)+[A-Za-z0-9]{2,3}/";
		// 注册人邮箱错误
		if(!preg_match($regYX,$mail)){
			$return["status"] = false;
			$return["msg"] = business_code(-27);
			return $return;
		}
		$api_config = WebSiteConfig(2);//获取网站配置
		$api_access = $api_config["api_access"] + 0;
		$api_access = $api_access ? $api_access : 1;
		$agent = new AgentAide(1,$api_access);
		$transaction = $agent->servant;
		$ptype = GD::PTYPE_DOMAIN;
		$pname = "validateemail";
		$tid = GD::TID_DOMAIN;
		$ownerEmail = $mail;
		$log_info = "ptype:".$ptype."-pname:".$pname."-tid:".$tid."-ownerEmail:".$ownerEmail;
		try{
			$result = $transaction->domain_validate_email($ownerEmail);
			api_log($uid,$log_info,$result,"(万网)邮箱验证");
		}catch(\Exception $e){
			api_log($uid,$log_info,$e->getMessage(),"(万网)邮箱验证失败");
			$return["status"] = false;
			$return["msg"] = business_code(-9);
			return $return;
		}
		$xstr = json_decode($result,true);
		if($xstr['code'] === 0){
			$return["status"] = true;
			$return["msg"] = "该邮箱已验证！";
			return $return;
		}else{
			if($xstr['code'] == 1120){
				$return["status"] = false;
				$return["msg"] = "验证邮件发送成功，请查看邮箱并验证邮箱！";
				return $return;
			}
			if($xstr['code'] == 8021){
				$return["status"] = false;
				$return["msg"] = "验证邮件已发送，请查看邮箱并验证邮箱！";
				return $return;
			}
			$return["status"] = false;
			$return["msg"] = business_code($xstr['code']);
			return $return;
		}
	}
}